# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Montana."""


ABSAROKEE_CDP = "00175"
ACTON_CDP = "00400"
ALBERTON_TOWN = "00700"
ALDER_CDP = "00850"
ALZADA_CDP = "01300"
AMSTERDAM_CDP = "01525"
ANACONDA_DEER_LODGE_COUNTY = "01675"
ANTELOPE_CDP = "02050"
ARGENTA_CDP = "02350"
ARLEE_CDP = "02425"
ASHLAND_CDP = "02800"
AUGUSTA_CDP = "03025"
AVON_CDP = "03175"
AYERS_RANCH_COLONY_CDP = "03196"
AZURE_CDP = "03212"
BABB_CDP = "03250"
BAINVILLE_TOWN = "03400"
BAKER_CITY = "03475"
BALLANTINE_CDP = "03625"
BASIN_CDP = "04150"
BATAVIA_CDP = "04230"
BEAR_DANCE_CDP = "04410"
BEARCREEK_TOWN = "04300"
BEAVER_CREEK_CDP = "04575"
BELFRY_CDP = "04900"
BELGRADE_CITY = "04975"
BELKNAP_CDP = "05050"
BELT_TOWN = "05275"
BIDDLE_CDP = "05650"
BIG_ARM_CDP = "05800"
BIG_SANDY_TOWN = "06250"
BIG_SKY_CDP = "06325"
BIG_SKY_COLONY_CDP = "06410"
BIG_STONE_COLONY_CDP = "06440"
BIG_TIMBER_CITY = "06475"
BIGFORK_CDP = "05875"
BILLINGS_CITY = "06550"
BIRCH_CREEK_COLONY_CDP = "06815"
BIRNEY_CDP = "06925"
BLACK_EAGLE_CDP = "07150"
BLACKFOOT_CDP = "07300"
BLOOMFIELD_CDP = "07675"
BONEAU_CDP = "08162"
BONNER_WEST_RIVERSIDE_CDP = "08462"
BOULDER_CITY = "08575"
BOX_ELDER_CDP = "08725"
BOYD_CDP = "08800"
BOZEMAN_CITY = "08950"
BRADY_CDP = "09250"
BRANDON_CDP = "09400"
BRIDGER_CDP = "09500"
BRIDGER_TOWN = "09475"
BROADUS_TOWN = "09700"
BROADVIEW_TOWN = "09775"
BROCKTON_CDP = "10000"
BROCKWAY_CDP = "10075"
BROOKS_CDP = "10150"
BROWNING_TOWN = "10375"
BULL_LAKE_CDP = "10935"
BUSBY_CDP = "11200"
BUTTE_SILVER_BOW_BALANCE = "11397"
BYNUM_CDP = "11500"
CAMAS_CDP = "11800"
CAMP_THREE_CDP = "11995"
CAMROSE_COLONY_CDP = "11999"
CANYON_CREEK_CDP = "12025"
CARDWELL_CDP = "12400"
CARLTON_CDP = "12435"
CARTER_CDP = "12625"
CASCADE_COLONY_CDP = "12783"
CASCADE_TOWN = "12775"
CENTERVILLE_CDP = "13375"
CHARLO_CDP = "13900"
CHARLOS_HEIGHTS_CDP = "13975"
CHESTER_TOWN = "14200"
CHINOOK_CITY = "14575"
CHOTEAU_CITY = "14650"
CHURCHILL_CDP = "14875"
CIRCLE_TOWN = "14950"
CLANCY_CDP = "15100"
CLINTON_CDP = "15475"
CLYDE_PARK_TOWN = "15550"
COFFEE_CREEK_CDP = "16000"
COLSTRIP_CITY = "16525"
COLUMBIA_FALLS_CITY = "16600"
COLUMBUS_TOWN = "16825"
CONDON_CDP = "17050"
CONNER_CDP = "17200"
CONRAD_CITY = "17275"
COOKE_CITY_CDP = "17350"
CORAM_CDP = "17500"
CORVALLIS_CDP = "17725"
CORWIN_SPRINGS_CDP = "17800"
CRAIG_CDP = "18025"
CRANE_CDP = "18100"
CROW_AGENCY_CDP = "18250"
CULBERTSON_TOWN = "18475"
CUSTER_CDP = "18700"
CUT_BANK_CITY = "18775"
CYR_CDP = "18850"
DANVERS_CDP = "19225"
DARBY_TOWN = "19300"
DAYTON_CDP = "19525"
DE_BORGIA_CDP = "19675"
DEER_LODGE_CITY = "19825"
DEERFIELD_COLONY_CDP = "19800"
DELL_CDP = "20050"
DENTON_TOWN = "20425"
DEWEY_CDP = "20725"
DILLON_CITY = "20800"
DIXON_CDP = "20950"
DODSON_TOWN = "21025"
DRUMMOND_TOWN = "21850"
DUNCAN_RANCH_COLONY_CDP = "22130"
DUPUYER_CDP = "22450"
DUTTON_TOWN = "22600"
EAGLE_CREEK_COLONY_CDP = "22655"
EAST_END_COLONY_CDP = "22943"
EAST_GLACIER_PARK_VILLAGE_CDP = "22985"
EAST_HELENA_CITY = "23125"
EAST_MALTA_COLONY_CDP = "23168"
EAST_MISSOULA_CDP = "23200"
EDGAR_CDP = "23500"
EKALAKA_TOWN = "23650"
ELKHORN_CDP = "23865"
ELLISTON_CDP = "23950"
ELMO_CDP = "24100"
EMIGRANT_CDP = "24325"
ENNIS_TOWN = "24475"
ESSEX_CDP = "24700"
EUREKA_TOWN = "24850"
EVARO_CDP = "25000"
EVERGREEN_CDP = "25075"
FAIR_HAVEN_COLONY_CDP = "25245"
FAIRFIELD_TOWN = "25225"
FAIRVIEW_TOWN = "25300"
FALLON_CDP = "25375"
FINLEY_POINT_CDP = "26226"
FISHTAIL_CDP = "26575"
FLAT_WILLOW_COLONY_CDP = "26733"
FLAXVILLE_TOWN = "26800"
FLORENCE_CDP = "26950"
FLOWEREE_CDP = "27025"
FORDS_CREEK_COLONY_CDP = "27360"
FOREST_HILL_VILLAGE_CDP = "27595"
FORSYTH_CITY = "27700"
FORT_BELKNAP_AGENCY_CDP = "27850"
FORT_BENTON_CITY = "28000"
FORT_PECK_TOWN = "28450"
FORT_SHAW_CDP = "28600"
FORT_SMITH_CDP = "28650"
FORTINE_CDP = "28150"
FORTY_MILE_COLONY_CDP = "28725"
FOUR_CORNERS_CDP = "28862"
FOX_CDP = "29050"
FOX_LAKE_CDP = "29087"
FRAZER_CDP = "29275"
FRENCHTOWN_CDP = "29350"
FROID_TOWN = "29500"
FROMBERG_TOWN = "29575"
GALLATIN_GATEWAY_CDP = "29875"
GALLATIN_RIVER_RANCH_CDP = "29885"
GARDINER_CDP = "29950"
GARRISON_CDP = "30175"
GERALDINE_TOWN = "30400"
GEYSER_CDP = "30550"
GIBSON_FLATS_CDP = "30625"
GILDFORD_CDP = "30700"
GILDFORD_COLONY_CDP = "30704"
GILMAN_CDP = "30750"
GLACIER_COLONY_CDP = "30925"
GLASGOW_CITY = "31075"
GLEN_CDP = "31375"
GLENDALE_COLONY_CDP = "31418"
GLENDIVE_CITY = "31450"
GOLDCREEK_CDP = "31825"
GOLDEN_VALLEY_COLONY_CDP = "31991"
GRANT_CDP = "32350"
GRASS_RANGE_TOWN = "32575"
GREAT_FALLS_CITY = "32800"
GREYCLIFF_CDP = "33250"
HALL_CDP = "33625"
HAMILTON_CITY = "33775"
HAPPYS_INN_CDP = "34110"
HARDIN_CITY = "34225"
HARDY_CDP = "34300"
HARLEM_CITY = "34375"
HARLOWTON_CITY = "34450"
HARRISON_CDP = "34525"
HARTLAND_COLONY_CDP = "34584"
HAUGAN_CDP = "34825"
HAVRE_NORTH_CDP = "35125"
HAVRE_CITY = "35050"
HAYS_CDP = "35275"
HEART_BUTTE_CDP = "35350"
HEBGEN_LAKE_ESTATES_CDP = "35435"
HELENA_FLATS_CDP = "35622"
HELENA_VALLEY_NORTHEAST_CDP = "35628"
HELENA_VALLEY_NORTHWEST_CDP = "35631"
HELENA_VALLEY_SOUTHEAST_CDP = "35634"
HELENA_VALLEY_WEST_CENTRAL_CDP = "35637"
HELENA_WEST_SIDE_CDP = "35640"
HELENA_CITY = "35600"
HELMVILLE_CDP = "35725"
HERON_CDP = "35875"
HERRON_CDP = "35912"
HIDDEN_LAKE_COLONY_CDP = "36055"
HIGHWOOD_CDP = "36250"
HILGER_CDP = "36325"
HILLDALE_COLONY_CDP = "36333"
HILLSIDE_COLONY_CDP = "36385"
HINGHAM_TOWN = "36400"
HINSDALE_CDP = "36475"
HOBSON_CITY = "36700"
HOGELAND_CDP = "36925"
HOMESTEAD_CDP = "37450"
HORIZON_COLONY_CDP = "37710"
HOT_SPRINGS_TOWN = "37825"
HUNGRY_HORSE_CDP = "38125"
HUNTLEY_CDP = "38200"
HUSON_CDP = "38275"
HYSHAM_TOWN = "38350"
INDIAN_SPRINGS_CDP = "38480"
INVERNESS_CDP = "38725"
ISMAY_TOWN = "38950"
JACKSON_CDP = "39025"
JARDINE_CDP = "39175"
JEFFERS_CDP = "39325"
JEFFERSON_CITY_CDP = "39400"
JETTE_CDP = "39627"
JOLIET_TOWN = "39700"
JOPLIN_CDP = "39775"
JORDAN_TOWN = "39925"
JUDITH_GAP_CITY = "40000"
KALISPELL_CITY = "40075"
KERR_CDP = "40355"
KEVIN_TOWN = "40525"
KICKING_HORSE_CDP = "40580"
KILA_CDP = "40675"
KILBY_BUTTE_COLONY_CDP = "40680"
KING_ARTHUR_PARK_CDP = "40685"
KING_RANCH_COLONY_CDP = "40718"
KINGS_POINT_CDP = "40725"
KINGSBURY_COLONY_CDP = "40720"
KLEIN_CDP = "41050"
KREMLIN_CDP = "41725"
LAKE_MARY_RONAN_CDP = "41910"
LAKESIDE_CDP = "41950"
LAKEVIEW_CDP = "42100"
LAME_DEER_CDP = "42250"
LANDUSKY_CDP = "42325"
LAREDO_CDP = "42475"
LAUREL_CITY = "42700"
LAVINA_TOWN = "42850"
LEWISTOWN_HEIGHTS_CDP = "43400"
LEWISTOWN_CITY = "43375"
LIBBY_CITY = "43450"
LIMA_TOWN = "43525"
LINCOLN_CDP = "43675"
LINDISFARNE_CDP = "43710"
LINDSAY_CDP = "43750"
LITTLE_BITTERROOT_LAKE_CDP = "43830"
LITTLE_BROWNING_CDP = "43835"
LIVINGSTON_CITY = "43975"
LOCKWOOD_CDP = "44200"
LODGE_GRASS_TOWN = "44275"
LODGE_POLE_CDP = "44350"
LOGAN_CDP = "44500"
LOLO_CDP = "44650"
LOMA_CDP = "44800"
LONEPINE_CDP = "44950"
LORING_COLONY_CDP = "45179"
LUTHER_CDP = "46150"
MALMSTROM_AFB_CDP = "47275"
MALTA_CITY = "47425"
MAMMOTH_CDP = "47460"
MANHATTAN_TOWN = "47575"
MARION_CDP = "47875"
MARTIN_CITY_CDP = "48100"
MARTINSDALE_CDP = "48175"
MARTINSDALE_COLONY_CDP = "48190"
MARYSVILLE_CDP = "48250"
MAVERICK_MOUNTAIN_CDP = "48585"
MAXVILLE_CDP = "48625"
MCALLISTER_CDP = "46225"
MEDICINE_LAKE_TOWN = "48775"
MELSTONE_TOWN = "49000"
MIDWAY_COLONY_CDP = "49418"
MILES_CITY_CITY = "49525"
MILFORD_COLONY_CDP = "49600"
MILLER_COLONY_CDP = "49750"
MISSOULA_CITY = "50200"
MOCCASIN_CDP = "50575"
MONARCH_CDP = "50950"
MONTANA_CITY_CDP = "51175"
MONTAQUA_CDP = "51475"
MOORE_TOWN = "51550"
MOUNTAIN_VIEW_COLONY_CDP = "52185"
MUDDY_CDP = "52315"
MUSSELSHELL_CDP = "52600"
NASHUA_TOWN = "52900"
NEIHART_TOWN = "53200"
NEW_MIAMI_COLONY_CDP = "53476"
NEW_ROCKPORT_COLONY_CDP = "53500"
NIARADA_CDP = "53725"
NIBBE_CDP = "53800"
NORRIS_CDP = "54475"
NORTH_BROWNING_CDP = "54510"
NORTH_HARLEM_COLONY_CDP = "54684"
NOXON_CDP = "54925"
NYE_CDP = "55075"
OLD_AGENCY_CDP = "55260"
OLNEY_CDP = "55450"
OPHEIM_TOWN = "55525"
ORCHARD_HOMES_CDP = "55675"
OUTLOOK_TOWN = "56050"
OVANDO_CDP = "56125"
PABLO_CDP = "56350"
PARADISE_CDP = "56425"
PARK_CITY_CDP = "56575"
PARKER_SCHOOL_CDP = "56650"
PEERLESS_CDP = "56800"
PENDROY_CDP = "56875"
PHILIPSBURG_TOWN = "57175"
PILTZVILLE_CDP = "57475"
PINE_CREEK_CDP = "57550"
PINESDALE_TOWN = "57700"
PINNACLE_CDP = "57775"
PIONEER_JUNCTION_CDP = "57950"
PLAINS_TOWN = "58150"
PLEASANT_VALLEY_COLONY_CDP = "58310"
PLENTYWOOD_CITY = "58375"
PLEVNA_TOWN = "58450"
POLEBRIDGE_CDP = "58675"
POLSON_CITY = "58750"
POMPEYS_PILLAR_CDP = "58825"
PONDERA_COLONY_CDP = "58834"
PONDEROSA_PINES_CDP = "58840"
PONY_CDP = "58900"
POPLAR_CITY = "58975"
POTOMAC_CDP = "59350"
POWER_CDP = "59500"
PRAIRIE_ELK_COLONY_CDP = "59650"
PRAY_CDP = "59725"
PRYOR_CDP = "59950"
RACETRACK_CDP = "60400"
RADER_CREEK_CDP = "60450"
RADERSBURG_CDP = "60475"
RAPELJE_CDP = "60850"
RAVALLI_CDP = "61075"
RAYNESFORD_CDP = "61300"
RED_LODGE_CITY = "61525"
REDSTONE_CDP = "61675"
REED_POINT_CDP = "61900"
RESERVE_CDP = "62125"
REXFORD_TOWN = "62200"
RHODES_CDP = "62230"
RICEVILLE_CDP = "62245"
RICHEY_TOWN = "62275"
RIMINI_CDP = "62650"
RIMROCK_COLONY_CDP = "62825"
RIVERBEND_CDP = "63042"
RIVERVIEW_COLONY_CDP = "63266"
ROBERTS_CDP = "63400"
ROCKPORT_COLONY_CDP = "63590"
ROCKVALE_CDP = "63700"
ROCKY_BOY_WEST_CDP = "63928"
ROCKY_BOYS_AGENCY_CDP = "63900"
ROCKY_POINT_CDP = "63940"
ROLLINS_CDP = "64075"
RONAN_CITY = "64150"
ROSCOE_CDP = "64300"
ROSEBUD_CDP = "64375"
ROUNDUP_CITY = "64525"
ROY_CDP = "64675"
RUDYARD_CDP = "64900"
RYEGATE_TOWN = "64975"
SACO_TOWN = "65050"
SADDLE_BUTTE_CDP = "65065"
SAGE_CREEK_COLONY_CDP = "65160"
SALTESE_CDP = "65875"
SAND_COULEE_CDP = "65950"
SANGREY_CDP = "66212"
SANTA_RITA_CDP = "66250"
SAPPHIRE_RIDGE_CDP = "66317"
SAVAGE_CDP = "66550"
SCOBEY_CITY = "66925"
SEDAN_CDP = "67075"
SEELEY_LAKE_CDP = "67150"
SEVILLE_COLONY_CDP = "67192"
SHAWMUT_CDP = "67225"
SHELBY_CITY = "67450"
SHEPHERD_CDP = "67525"
SHERIDAN_TOWN = "67600"
SIDNEY_CITY = "67900"
SILESIA_CDP = "68050"
SILVER_GATE_CDP = "68425"
SILVER_STAR_CDP = "68500"
SIMMS_CDP = "68575"
SLEEPING_BUFFALO_CDP = "68985"
SNOWSLIP_CDP = "69345"
SOMERS_CDP = "69475"
SOUTH_BROWNING_CDP = "69680"
SOUTH_GLASTONBURY_CDP = "69713"
SOUTH_HILLS_CDP = "69725"
SPOKANE_CREEK_CDP = "69900"
SPRING_CREEK_COLONY_CDP = "70000"
SPRINGDALE_CDP = "70150"
SPRINGDALE_COLONY_CDP = "70225"
SPRINGHILL_CDP = "70375"
SPRINGWATER_COLONY_CDP = "70434"
SQUARE_BUTTE_CDP = "70600"
ST_IGNATIUS_TOWN = "65275"
ST_MARIE_CDP = "65400"
ST_MARY_CDP = "65425"
ST_PIERRE_CDP = "65537"
ST_REGIS_CDP = "65575"
ST_XAVIER_CDP = "65650"
STANFORD_TOWN = "70675"
STARR_SCHOOL_CDP = "70825"
STEVENSVILLE_TOWN = "71200"
STOCKETT_CDP = "71350"
STRYKER_CDP = "71575"
SULA_CDP = "71800"
SUN_PRAIRIE_CDP = "72380"
SUN_RIVER_CDP = "72475"
SUNBURST_TOWN = "72175"
SUNNYBROOK_COLONY_CDP = "72305"
SUPERIOR_TOWN = "72625"
SURPRISE_CREEK_COLONY_CDP = "72660"
SWAN_LAKE_CDP = "72850"
SWEET_GRASS_CDP = "73075"
SYLVANITE_CDP = "73165"
TERRY_TOWN = "73675"
THE_SILOS_CDP = "73760"
THOMPSON_FALLS_CITY = "73825"
THREE_FORKS_CITY = "73975"
TOSTON_CDP = "74500"
TOWNSEND_CITY = "74575"
TRACY_CDP = "74650"
TREGO_CDP = "74725"
TROUT_CREEK_CDP = "74950"
TROY_CITY = "75025"
TURAH_CDP = "75175"
TURNER_CDP = "75250"
TURNER_COLONY_CDP = "75258"
TURTLE_LAKE_CDP = "75287"
TWIN_BRIDGES_TOWN = "75475"
TWIN_CREEKS_CDP = "75550"
TWIN_HILLS_COLONY_CDP = "75590"
TWODOT_CDP = "75700"
ULM_CDP = "75775"
UNIONVILLE_CDP = "75905"
UTICA_CDP = "76075"
VALIER_TOWN = "76225"
VAUGHN_CDP = "76675"
VICTOR_CDP = "76900"
VIDA_CDP = "76975"
VIRGINIA_CITY_TOWN = "77125"
WALKERVILLE_TOWN = "77650"
WARM_SPRING_CREEK_CDP = "78143"
WEEKSVILLE_CDP = "78775"
WEST_GLACIER_CDP = "79075"
WEST_GLENDIVE_CDP = "79086"
WEST_HAVRE_CDP = "79098"
WEST_KOOTENAI_CDP = "79105"
WEST_YELLOWSTONE_TOWN = "79525"
WESTBY_TOWN = "78925"
WHEATLAND_CDP = "79695"
WHITE_HAVEN_CDP = "79935"
WHITE_SULPHUR_SPRINGS_CITY = "80050"
WHITEFISH_CITY = "79825"
WHITEHALL_TOWN = "79900"
WHITETAIL_CDP = "80125"
WHITEWATER_CDP = "80200"
WHITLASH_CDP = "80275"
WIBAUX_TOWN = "80350"
WILLOW_CREEK_CDP = "80800"
WILSALL_CDP = "80875"
WINDHAM_CDP = "80950"
WINEGLASS_CDP = "80975"
WINIFRED_TOWN = "81025"
WINNETT_TOWN = "81100"
WINSTON_CDP = "81175"
WISDOM_CDP = "81250"
WISE_RIVER_CDP = "81325"
WOLF_CREEK_CDP = "81400"
WOLF_POINT_CITY = "81475"
WOODS_BAY_CDP = "81700"
WORDEN_CDP = "81925"
WYE_CDP = "81980"
WYOLA_CDP = "82075"
YAAK_CDP = "82130"
YORK_CDP = "82525"
ZENITH_COLONY_CDP = "82635"
ZORTMAN_CDP = "82675"
ZURICH_CDP = "82750"



# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Iowa."""


ADAIR = "001"
ADAMS = "003"
ALLAMAKEE = "005"
APPANOOSE = "007"
AUDUBON = "009"
BENTON = "011"
BLACK_HAWK = "013"
BOONE = "015"
BREMER = "017"
BUCHANAN = "019"
BUENA_VISTA = "021"
BUTLER = "023"
CALHOUN = "025"
CARROLL = "027"
CASS = "029"
CEDAR = "031"
CERRO_GORDO = "033"
CHEROKEE = "035"
CHICKASAW = "037"
CLARKE = "039"
CLAY = "041"
CLAYTON = "043"
CLINTON = "045"
CRAWFORD = "047"
DALLAS = "049"
DAVIS = "051"
DECATUR = "053"
DELAWARE = "055"
DES_MOINES = "057"
DICKINSON = "059"
DUBUQUE = "061"
EMMET = "063"
FAYETTE = "065"
FLOYD = "067"
FRANKLIN = "069"
FREMONT = "071"
GREENE = "073"
GRUNDY = "075"
GUTHRIE = "077"
HAMILTON = "079"
HANCOCK = "081"
HARDIN = "083"
HARRISON = "085"
HENRY = "087"
HOWARD = "089"
HUMBOLDT = "091"
IDA = "093"
IOWA = "095"
JACKSON = "097"
JASPER = "099"
JEFFERSON = "101"
JOHNSON = "103"
JONES = "105"
KEOKUK = "107"
KOSSUTH = "109"
LEE = "111"
LINN = "113"
LOUISA = "115"
LUCAS = "117"
LYON = "119"
MADISON = "121"
MAHASKA = "123"
MARION = "125"
MARSHALL = "127"
MILLS = "129"
MITCHELL = "131"
MONONA = "133"
MONROE = "135"
MONTGOMERY = "137"
MUSCATINE = "139"
OBRIEN = "141"
OSCEOLA = "143"
PAGE = "145"
PALO_ALTO = "147"
PLYMOUTH = "149"
POCAHONTAS = "151"
POLK = "153"
POTTAWATTAMIE = "155"
POWESHIEK = "157"
RINGGOLD = "159"
SAC = "161"
SCOTT = "163"
SHELBY = "165"
SIOUX = "167"
STORY = "169"
TAMA = "171"
TAYLOR = "173"
UNION = "175"
VAN_BUREN = "177"
WAPELLO = "179"
WARREN = "181"
WASHINGTON = "183"
WAYNE = "185"
WEBSTER = "187"
WINNEBAGO = "189"
WINNESHIEK = "191"
WOODBURY = "193"
WORTH = "195"
WRIGHT = "197"



# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Tennessee."""


ADAMS_CITY = "00200"
ADAMSVILLE_TOWN = "00240"
ALAMO_TOWN = "00440"
ALCOA_CITY = "00540"
ALEXANDRIA_TOWN = "00620"
ALGOOD_CITY = "00640"
ALLARDT_CITY = "00660"
ALTAMONT_TOWN = "00940"
ANDERSONVILLE_CDP = "01220"
APISON_CDP = "01480"
ARDMORE_CITY = "01640"
ARLINGTON_TOWN = "01740"
ASHLAND_CITY_TOWN = "02180"
ATHENS_CITY = "02320"
ATOKA_TOWN = "02340"
ATWOOD_TOWN = "02380"
AUBURNTOWN_TOWN = "02400"
BAILEYTON_TOWN = "02780"
BANEBERRY_CITY = "03078"
BANNER_HILL_CDP = "03120"
BARTLETT_CITY = "03440"
BAXTER_TOWN = "03680"
BEAN_STATION_CITY = "03760"
BEECH_BLUFF_CDP = "04000"
BEERSHEBA_SPRINGS_TOWN = "04240"
BELL_BUCKLE_TOWN = "04460"
BELLE_MEADE_CITY = "04620"
BELLS_CITY = "04720"
BELVIDERE_CDP = "04920"
BENTON_TOWN = "05040"
BERRY_HILL_CITY = "05140"
BETHEL_SPRINGS_TOWN = "05380"
BETHPAGE_CDP = "05500"
BIG_ROCK_CDP = "05840"
BIG_SANDY_TOWN = "05860"
BILTMORE_CDP = "06020"
BLAINE_CITY = "06340"
BLANCHE_CDP = "06440"
BLOOMINGDALE_CDP = "06640"
BLOUNTVILLE_CDP = "06740"
BLUFF_CITY_CITY = "06960"
BOGOTA_CDP = "07120"
BOLIVAR_CITY = "07180"
BON_AIR_CDP = "07240"
BON_AQUA_JUNCTION_CDP = "07280"
BOWMAN_CDP = "07620"
BRADEN_TOWN = "07840"
BRADFORD_TOWN = "07860"
BRANSFORD_CDP = "08080"
BRENTWOOD_CITY = "08280"
BRICEVILLE_CDP = "08400"
BRIGHTON_TOWN = "08500"
BRISTOL_CITY = "08540"
BROWNSVILLE_CITY = "08920"
BRUCETON_TOWN = "08960"
BUCHANAN_CDP = "09200"
BULLS_GAP_TOWN = "09560"
BURLISON_TOWN = "09860"
BURNS_TOWN = "09880"
BUTLER_CDP = "10080"
BYRDSTOWN_TOWN = "10180"
CALHOUN_TOWN = "10440"
CAMDEN_CITY = "10560"
CARTHAGE_TOWN = "11280"
CARYVILLE_TOWN = "11360"
CASTALIAN_SPRINGS_CDP = "11440"
CEDAR_HILL_CITY = "11980"
CELINA_CITY = "12100"
CENTERTOWN_TOWN = "12380"
CENTERVILLE_TOWN = "12420"
CENTRAL_CDP = "12460"
CHAPEL_HILL_TOWN = "12880"
CHARLESTON_CITY = "13020"
CHARLOTTE_TOWN = "13080"
CHATTANOOGA_CITY = "14000"
CHESTERFIELD_CDP = "14220"
CHEWALLA_CDP = "14520"
CHILDERS_HILL_CDP = "14620"
CHRISTIANA_CDP = "14860"
CHURCH_HILL_CITY = "14980"
CLARKRANGE_CDP = "15120"
CLARKSBURG_TOWN = "15140"
CLARKSVILLE_CITY = "15160"
CLEVELAND_CITY = "15400"
CLIFTON_CITY = "15480"
CLINTON_CITY = "15580"
COALFIELD_CDP = "15880"
COALMONT_CITY = "15920"
COKER_CREEK_CDP = "16060"
COLLEGEDALE_CITY = "16300"
COLLIERVILLE_TOWN = "16420"
COLLINWOOD_CITY = "16480"
COLONIAL_HEIGHTS_CDP = "16500"
COLUMBIA_CITY = "16540"
CONASAUGA_CDP = "16740"
COOKEVILLE_CITY = "16920"
COOPERTOWN_TOWN = "16980"
COPPERHILL_CITY = "17000"
CORNERSVILLE_TOWN = "17180"
COSBY_CDP = "17300"
COTTAGE_GROVE_TOWN = "17340"
COTTONTOWN_CDP = "17420"
COUNCE_CDP = "17520"
COVINGTON_CITY = "17680"
COWAN_CITY = "17700"
CRAB_ORCHARD_CITY = "17840"
CROSS_PLAINS_CITY = "18420"
CROSSVILLE_CITY = "18540"
CRUMP_CITY = "18620"
CUMBERLAND_CITY_TOWN = "18820"
CUMBERLAND_GAP_TOWN = "18880"
DANCYVILLE_CDP = "19360"
DANDRIDGE_TOWN = "19380"
DARDEN_CDP = "19500"
DAYTON_CITY = "19700"
DECATUR_TOWN = "19880"
DECATURVILLE_TOWN = "19900"
DECHERD_CITY = "19920"
DELANO_CDP = "20080"
DELLROSE_CDP = "20120"
DICKSON_CITY = "20620"
DODSON_BRANCH_CDP = "20930"
DOVER_CITY = "21400"
DOWELLTOWN_TOWN = "21420"
DOYLE_TOWN = "21500"
DRESDEN_TOWN = "21540"
DUCKTOWN_CITY = "21740"
DUKEDOM_CDP = "21860"
DUNLAP_CITY = "22000"
DYER_CITY = "22180"
DYERSBURG_CITY = "22200"
EAGLETON_VILLAGE_CDP = "22340"
EAGLEVILLE_CITY = "22360"
EAST_CLEVELAND_CDP = "22500"
EAST_RIDGE_CITY = "22720"
EASTVIEW_TOWN = "22920"
ELGIN_CDP = "23440"
ELIZABETHTON_CITY = "23500"
ELKTON_CITY = "23660"
EMBREEVILLE_CDP = "23880"
ENGLEWOOD_TOWN = "24040"
ENVILLE_TOWN = "24240"
ERIN_CITY = "24320"
ERWIN_TOWN = "24360"
ESSARY_SPRINGS_CDP = "24400"
ESTILL_SPRINGS_TOWN = "24440"
ETHRIDGE_TOWN = "24460"
ETOWAH_CITY = "24480"
EVA_CDP = "24640"
FAIRFIELD_CDP = "24960"
FAIRFIELD_GLADE_CDP = "24980"
FAIRGARDEN_CDP = "24990"
FAIRMOUNT_CDP = "25080"
FAIRVIEW_CITY = "25440"
FALL_BRANCH_CDP = "25540"
FALLING_WATER_CDP = "25560"
FARNER_CDP = "25740"
FARRAGUT_TOWN = "25760"
FAYETTEVILLE_CITY = "25920"
FINCASTLE_CDP = "26120"
FINGER_CITY = "26160"
FINLEY_CDP = "26180"
FLAT_TOP_MOUNTAIN_CDP = "26490"
FLINTVILLE_CDP = "26580"
FOREST_HILLS_CITY = "27020"
FOWLKES_CDP = "27640"
FRANKEWING_CDP = "27700"
FRANKLIN_CITY = "27740"
FRIENDSHIP_CITY = "27960"
FRIENDSVILLE_CITY = "28060"
GADSDEN_TOWN = "28380"
GAINESBORO_TOWN = "28420"
GALLATIN_CITY = "28540"
GALLAWAY_CITY = "28560"
GARLAND_TOWN = "28680"
GATES_TOWN = "28740"
GATLINBURG_CITY = "28800"
GERMANTOWN_CITY = "28960"
GIBSON_TOWN = "29020"
GILT_EDGE_CITY = "29160"
GLADEVILLE_CDP = "29260"
GLEASON_TOWN = "29300"
GOODLETTSVILLE_CITY = "29920"
GORDONSVILLE_TOWN = "30120"
GRABALL_CDP = "30220"
GRAND_JUNCTION_CITY = "30280"
GRAY_CDP = "30700"
GRAYSVILLE_TOWN = "30760"
GREEN_HILL_CDP = "31100"
GREENBACK_CITY = "30880"
GREENBRIER_TOWN = "30960"
GREENEVILLE_TOWN = "30980"
GREENFIELD_CITY = "31000"
GREENVALE_CDP = "31220"
GRIFFITH_CREEK_CDP = "31400"
GRIMSLEY_CDP = "31420"
GRUETLI_LAAGER_CITY = "31490"
GUYS_TOWN = "31680"
HALLS_CDP = "31810"
HALLS_TOWN = "31820"
HAMPTON_CDP = "32040"
HARRIMAN_CITY = "32520"
HARRISON_CDP = "32600"
HARROGATE_CITY = "32640"
HARTSVILLE_TROUSDALE_COUNTY = "32742"
HELENWOOD_CDP = "33120"
HENDERSON_CITY = "33260"
HENDERSONVILLE_CITY = "33280"
HENNING_TOWN = "33360"
HENRY_TOWN = "33400"
HICKMAN_CDP = "33680"
HICKORY_VALLEY_TOWN = "33920"
HILHAM_CDP = "34580"
HILLSBORO_CDP = "34700"
HOHENWALD_CITY = "35160"
HOLLADAY_CDP = "35220"
HOLLOW_ROCK_TOWN = "35280"
HOPEWELL_CDP = "35880"
HORNBEAK_TOWN = "36000"
HORNSBY_TOWN = "36080"
HUMBOLDT_CITY = "36460"
HUNTER_CDP = "36500"
HUNTINGDON_TOWN = "36580"
HUNTLAND_TOWN = "36600"
HUNTSVILLE_TOWN = "36640"
HURON_CDP = "36700"
IRON_CITY_CDP = "37360"
JACKS_CREEK_CDP = "37620"
JACKSBORO_TOWN = "37600"
JACKSON_CITY = "37640"
JAMESTOWN_CITY = "37780"
JASPER_TOWN = "37820"
JEFFERSON_CITY_CITY = "37960"
JELLICO_CITY = "38020"
JOHN_SEVIER_CDP = "38300"
JOHNSON_CITY_CITY = "38320"
JONESBOROUGH_TOWN = "38540"
KAHITE_CDP = "38765"
KARNS_CDP = "38800"
KENTON_TOWN = "39140"
KIMBALL_TOWN = "39400"
KINGSPORT_CITY = "39560"
KINGSTON_SPRINGS_TOWN = "39660"
KINGSTON_CITY = "39620"
KNOXVILLE_CITY = "40000"
LA_FOLLETTE_CITY = "40180"
LA_GRANGE_TOWN = "40200"
LA_VERGNE_CITY = "41200"
LAFAYETTE_CITY = "40160"
LAKE_TANSI_CDP = "40560"
LAKELAND_CITY = "40350"
LAKESITE_CITY = "40540"
LAKEWOOD_PARK_CDP = "40732"
LAVINIA_CDP = "41240"
LAWRENCEBURG_CITY = "41340"
LEBANON_CITY = "41520"
LENOIR_CITY_CITY = "41760"
LENOX_CDP = "41780"
LEOMA_CDP = "41800"
LEWISBURG_CITY = "41860"
LEXINGTON_CITY = "41980"
LIBERTY_TOWN = "42040"
LINDEN_TOWN = "42720"
LIVINGSTON_TOWN = "43140"
LOBELVILLE_CITY = "43160"
LONE_OAK_CDP = "43420"
LOOKOUT_MOUNTAIN_TOWN = "43640"
LORETTO_CITY = "43700"
LOUDON_CITY = "43780"
LOUISVILLE_CITY = "43820"
LURAY_CDP = "44200"
LUTTRELL_TOWN = "44300"
LYLES_CDP = "44360"
LYNCHBURG = "44382"
LYNNVILLE_TOWN = "44420"
MADISONVILLE_CITY = "45320"
MANCHESTER_CITY = "45500"
MARTIN_CITY = "46240"
MARYVILLE_CITY = "46380"
MASCOT_CDP = "46400"
MASON_TOWN = "46420"
MAURY_CITY_TOWN = "46540"
MAYLAND_CDP = "46680"
MAYNARDVILLE_CITY = "46700"
MCDONALD_CDP = "44700"
MCEWEN_CITY = "44840"
MCKENZIE_CITY = "44940"
MCLEMORESVILLE_TOWN = "45000"
MCMINNVILLE_CITY = "45100"
MEDINA_CITY = "47000"
MEDON_CITY = "47020"
MEMPHIS_CITY = "48000"
MERCER_CDP = "48120"
MICHIE_TOWN = "48180"
MIDDLE_VALLEY_CDP = "48360"
MIDDLETON_CITY = "48340"
MIDTOWN_CDP = "48460"
MILAN_CITY = "48660"
MILLEDGEVILLE_TOWN = "48920"
MILLERSVILLE_CITY = "48980"
MILLINGTON_CITY = "49060"
MINOR_HILL_CITY = "49360"
MISTON_CDP = "49420"
MITCHELLVILLE_CITY = "49460"
MONTEAGLE_TOWN = "49740"
MONTEREY_TOWN = "49760"
MOORESBURG_CDP = "49940"
MORRIS_CHAPEL_CDP = "50200"
MORRISON_TOWN = "50220"
MORRISTOWN_CITY = "50280"
MOSCOW_CITY = "50300"
MOSHEIM_TOWN = "50320"
MOUNT_CARMEL_TOWN = "50580"
MOUNT_JULIET_CITY = "50780"
MOUNT_PLEASANT_CITY = "51080"
MOUNTAIN_CITY_TOWN = "50400"
MOWBRAY_MOUNTAIN_CDP = "51402"
MUNFORD_CITY = "51540"
MURFREESBORO_CITY = "51560"
NASHVILLE_DAVIDSON_METROPOLITAN_GOVERNMENT_BALANCE = "52006"
NEW_DEAL_CDP = "52520"
NEW_HOPE_CITY = "52780"
NEW_JOHNSONVILLE_CITY = "52820"
NEW_MARKET_TOWN = "52940"
NEW_TAZEWELL_TOWN = "53140"
NEW_UNION_CDP = "53240"
NEWBERN_TOWN = "52400"
NEWPORT_CITY = "53000"
NIOTA_CITY = "53380"
NIXON_CDP = "53400"
NOLENSVILLE_TOWN = "53460"
NORENE_CDP = "53520"
NORMANDY_TOWN = "53580"
NORRIS_CITY = "53600"
OAK_GROVE_CDP_SUMNER_COUNTY = "54640"
OAK_GROVE_CDP_WASHINGTON_COUNTY = "54700"
OAK_HILL_CITY = "54780"
OAK_RIDGE_CITY = "55120"
OAKDALE_TOWN = "54280"
OAKLAND_TOWN = "54920"
OBION_TOWN = "55240"
OCOEE_CDP = "55280"
OLIVER_SPRINGS_TOWN = "55800"
OLIVET_CDP = "55820"
ONEIDA_TOWN = "55860"
OOLTEWAH_CDP = "55900"
OREBANK_CDP = "55980"
ORLINDA_CITY = "56020"
ORME_TOWN = "56040"
PALMER_TOWN = "56560"
PALMERSVILLE_CDP = "56580"
PARIS_CITY = "56720"
PARK_CITY_CDP = "56800"
PARKERS_CROSSROADS_CITY = "56870"
PARROTTSVILLE_TOWN = "57040"
PARSONS_CITY = "57080"
PEGRAM_TOWN = "57480"
PELHAM_CDP = "57500"
PETERSBURG_TOWN = "57740"
PETROS_CDP = "57780"
PHILADELPHIA_CITY = "57900"
PIGEON_FORGE_CITY = "58080"
PIKEVILLE_CITY = "58120"
PINE_CREST_CDP = "58240"
PINSON_CDP = "58780"
PIPERTON_CITY = "58840"
PITTMAN_CENTER_TOWN = "58940"
PLAINVIEW_CITY = "59020"
PLEASANT_HILL_TOWN = "59240"
PLEASANT_VIEW_CITY = "59560"
POCAHONTAS_CDP = "59640"
PORTLAND_CITY = "60280"
POWELL_CDP = "60480"
POWELLS_CROSSROADS_TOWN = "60500"
PROSPECT_CDP = "60800"
PULASKI_CITY = "61040"
PURYEAR_CITY = "61160"
RAMER_CITY = "61520"
RANDOLPH_CDP = "61560"
RARITY_BAY_CDP = "61635"
RED_BANK_CITY = "61960"
RED_BOILING_SPRINGS_CITY = "62000"
RICEVILLE_CDP = "62580"
RIDGELY_TOWN = "63060"
RIDGESIDE_CITY = "63080"
RIDGETOP_CITY = "63140"
RIPLEY_CITY = "63340"
RIVES_TOWN = "63800"
ROAN_MOUNTAIN_CDP = "63840"
ROBBINS_CDP = "63920"
ROCKFORD_CITY = "64160"
ROCKVALE_CDP = "64400"
ROCKWOOD_CITY = "64440"
ROCKY_TOP_CITY = "64668"
ROGERSVILLE_TOWN = "64820"
ROSSVILLE_TOWN = "65240"
RURAL_HILL_CDP = "65642"
RUSSELLVILLE_CDP = "65740"
RUTHERFORD_TOWN = "65760"
RUTLEDGE_TOWN = "65820"
SALE_CREEK_CDP = "66220"
SALTILLO_TOWN = "66340"
SAMBURG_TOWN = "66360"
SARDIS_TOWN = "66660"
SAULSBURY_TOWN = "66680"
SAVANNAH_CITY = "66720"
SCOTTS_HILL_TOWN = "66880"
SELMER_TOWN = "66940"
SEQUATCHIE_CDP = "66960"
SEVIERVILLE_CITY = "67120"
SEWANEE_CDP = "67140"
SEYMOUR_CDP = "67200"
SHACKLE_ISLAND_CDP = "67230"
SHARON_TOWN = "67540"
SHELBYVILLE_CITY = "67760"
SHERWOOD_CDP = "67920"
SHILOH_CDP = "68040"
SIGNAL_MOUNTAIN_TOWN = "68540"
SILERTON_TOWN = "68560"
SLAYDEN_TOWN = "69080"
SMITHVILLE_CITY = "69320"
SMYRNA_TOWN = "69420"
SNEEDVILLE_TOWN = "69460"
SODDY_DAISY_CITY = "69560"
SOMERVILLE_TOWN = "69620"
SOUTH_CARTHAGE_TOWN = "69680"
SOUTH_CLEVELAND_CDP = "69740"
SOUTH_FULTON_CITY = "69900"
SOUTH_PITTSBURG_CITY = "70060"
SPARTA_CITY = "70180"
SPENCER_TOWN = "70240"
SPRING_CITY_TOWN = "70400"
SPRING_HILL_CITY = "70580"
SPRINGFIELD_CITY = "70500"
SPURGEON_CDP = "70680"
ST_JOSEPH_CITY = "66160"
STANTON_TOWN = "70820"
STANTONVILLE_TOWN = "70840"
STATESVILLE_CDP = "70900"
STRAWBERRY_PLAINS_CDP = "71500"
SULLIVAN_GARDENS_CDP = "71800"
SUMMERTOWN_CDP = "72040"
SUNBRIGHT_CITY = "72140"
SURGOINSVILLE_TOWN = "72380"
SWEETWATER_CITY = "72540"
TAFT_CDP = "72780"
TAZEWELL_TOWN = "73120"
TELFORD_CDP = "73220"
TELLICO_PLAINS_TOWN = "73260"
TELLICO_VILLAGE_CDP = "73270"
TENNESSEE_RIDGE_TOWN = "73460"
THOMPSONS_STATION_TOWN = "73900"
THREE_WAY_CITY = "74100"
TIPTONVILLE_TOWN = "74540"
TOONE_TOWN = "74640"
TOWNSEND_CITY = "74860"
TRACY_CITY_TOWN = "74880"
TRENTON_CITY = "75000"
TREZEVANT_TOWN = "75100"
TRIMBLE_TOWN = "75160"
TROY_TOWN = "75240"
TUCKERS_CROSSROADS_CDP = "75300"
TULLAHOMA_CITY = "75320"
TUSCULUM_CITY = "75560"
UNICOI_TOWN = "75820"
UNION_CITY_CITY = "75940"
UNIONVILLE_CDP = "76180"
VALLEY_FORGE_CDP = "76660"
VANLEER_TOWN = "76860"
VIOLA_TOWN = "77400"
VONORE_TOWN = "77480"
WALDEN_TOWN = "77540"
WALLAND_CDP = "77700"
WALNUT_GROVE_CDP_HARDIN_COUNTY = "77760"
WALNUT_GROVE_CDP_SUMNER_COUNTY = "77820"
WALNUT_HILL_CDP = "77900"
WALTERHILL_CDP = "77980"
WARTBURG_CITY = "78100"
WARTRACE_TOWN = "78120"
WATAUGA_CITY = "78240"
WATERTOWN_CITY = "78320"
WAVERLY_CITY = "78560"
WAYNESBORO_CITY = "78600"
WESTMORELAND_TOWN = "79420"
WESTPOINT_CDP = "79500"
WHITE_BLUFF_TOWN = "79980"
WHITE_HOUSE_CITY = "80200"
WHITE_PINE_TOWN = "80360"
WHITESIDE_CDP = "80500"
WHITEVILLE_TOWN = "80540"
WHITLOCK_CDP = "80580"
WHITWELL_CITY = "80620"
WILDERSVILLE_CDP = "80720"
WILDWOOD_CDP = "80740"
WILDWOOD_LAKE_CDP = "80760"
WILLISTON_CITY = "81020"
WINCHESTER_CITY = "81080"
WINFIELD_TOWN = "81280"
WOODBURY_TOWN = "81560"
WOODLAND_MILLS_CITY = "81700"
WRIGLEY_CDP = "82120"
WYNNBURG_CDP = "82200"
YORKVILLE_CITY = "82360"
YUMA_CDP = "82440"



# Copyright (c) 2023 Darren Erik Vengroff
"""Divisions."""


EAST_NORTH_CENTRAL_DIVISION = "3"
EAST_SOUTH_CENTRAL_DIVISION = "6"
MIDDLE_ATLANTIC_DIVISION = "2"
MOUNTAIN_DIVISION = "8"
NEW_ENGLAND_DIVISION = "1"
PACIFIC_DIVISION = "9"
SOUTH_ATLANTIC_DIVISION = "5"
WEST_NORTH_CENTRAL_DIVISION = "4"
WEST_SOUTH_CENTRAL_DIVISION = "7"



# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Puerto Rico."""


ADJUNTAS = "001"
AGUADA = "003"
AGUADILLA = "005"
AGUAS_BUENAS = "007"
AIBONITO = "009"
ARECIBO = "013"
ARROYO = "015"
ANASCO = "011"
BARCELONETA = "017"
BARRANQUITAS = "019"
BAYAMON = "021"
CABO_ROJO = "023"
CAGUAS = "025"
CAMUY = "027"
CANOVANAS = "029"
CAROLINA = "031"
CATANO = "033"
CAYEY = "035"
CEIBA = "037"
CIALES = "039"
CIDRA = "041"
COAMO = "043"
COMERIO = "045"
COROZAL = "047"
CULEBRA = "049"
DORADO = "051"
FAJARDO = "053"
FLORIDA = "054"
GUAYAMA = "057"
GUAYANILLA = "059"
GUAYNABO = "061"
GURABO = "063"
GUANICA = "055"
HATILLO = "065"
HORMIGUEROS = "067"
HUMACAO = "069"
ISABELA = "071"
JAYUYA = "073"
JUANA_DIAZ = "075"
JUNCOS = "077"
LAJAS = "079"
LARES = "081"
LAS_MARIAS = "083"
LAS_PIEDRAS = "085"
LOIZA = "087"
LUQUILLO = "089"
MANATI = "091"
MARICAO = "093"
MAUNABO = "095"
MAYAGUEZ = "097"
MOCA = "099"
MOROVIS = "101"
NAGUABO = "103"
NARANJITO = "105"
OROCOVIS = "107"
PATILLAS = "109"
PENUELAS = "111"
PONCE = "113"
QUEBRADILLAS = "115"
RINCON = "117"
RIO_GRANDE = "119"
SABANA_GRANDE = "121"
SALINAS = "123"
SAN_GERMAN = "125"
SAN_JUAN = "127"
SAN_LORENZO = "129"
SAN_SEBASTIAN = "131"
SANTA_ISABEL = "133"
TOA_ALTA = "135"
TOA_BAJA = "137"
TRUJILLO_ALTO = "139"
UTUADO = "141"
VEGA_ALTA = "143"
VEGA_BAJA = "145"
VIEQUES = "147"
VILLALBA = "149"
YABUCOA = "151"
YAUCO = "153"



# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in New Mexico."""


BERNALILLO = "001"
CATRON = "003"
CHAVES = "005"
CIBOLA = "006"
COLFAX = "007"
CURRY = "009"
DE_BACA = "011"
DONA_ANA = "013"
EDDY = "015"
GRANT = "017"
GUADALUPE = "019"
HARDING = "021"
HIDALGO = "023"
LEA = "025"
LINCOLN = "027"
LOS_ALAMOS = "028"
LUNA = "029"
MCKINLEY = "031"
MORA = "033"
OTERO = "035"
QUAY = "037"
RIO_ARRIBA = "039"
ROOSEVELT = "041"
SAN_JUAN = "045"
SAN_MIGUEL = "047"
SANDOVAL = "043"
SANTA_FE = "049"
SIERRA = "051"
SOCORRO = "053"
TAOS = "055"
TORRANCE = "057"
UNION = "059"
VALENCIA = "061"



# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Wisconsin."""


ADAMS = "001"
ASHLAND = "003"
BARRON = "005"
BAYFIELD = "007"
BROWN = "009"
BUFFALO = "011"
BURNETT = "013"
CALUMET = "015"
CHIPPEWA = "017"
CLARK = "019"
COLUMBIA = "021"
CRAWFORD = "023"
DANE = "025"
DODGE = "027"
DOOR = "029"
DOUGLAS = "031"
DUNN = "033"
EAU_CLAIRE = "035"
FLORENCE = "037"
FOND_DU_LAC = "039"
FOREST = "041"
GRANT = "043"
GREEN = "045"
GREEN_LAKE = "047"
IOWA = "049"
IRON = "051"
JACKSON = "053"
JEFFERSON = "055"
JUNEAU = "057"
KENOSHA = "059"
KEWAUNEE = "061"
LA_CROSSE = "063"
LAFAYETTE = "065"
LANGLADE = "067"
LINCOLN = "069"
MANITOWOC = "071"
MARATHON = "073"
MARINETTE = "075"
MARQUETTE = "077"
MENOMINEE = "078"
MILWAUKEE = "079"
MONROE = "081"
OCONTO = "083"
ONEIDA = "085"
OUTAGAMIE = "087"
OZAUKEE = "089"
PEPIN = "091"
PIERCE = "093"
POLK = "095"
PORTAGE = "097"
PRICE = "099"
RACINE = "101"
RICHLAND = "103"
ROCK = "105"
RUSK = "107"
SAUK = "111"
SAWYER = "113"
SHAWANO = "115"
SHEBOYGAN = "117"
ST_CROIX = "109"
TAYLOR = "119"
TREMPEALEAU = "121"
VERNON = "123"
VILAS = "125"
WALWORTH = "127"
WASHBURN = "129"
WASHINGTON = "131"
WAUKESHA = "133"
WAUPACA = "135"
WAUSHARA = "137"
WINNEBAGO = "139"
WOOD = "141"



# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in North Dakota."""


ADAMS = "001"
BARNES = "003"
BENSON = "005"
BILLINGS = "007"
BOTTINEAU = "009"
BOWMAN = "011"
BURKE = "013"
BURLEIGH = "015"
CASS = "017"
CAVALIER = "019"
DICKEY = "021"
DIVIDE = "023"
DUNN = "025"
EDDY = "027"
EMMONS = "029"
FOSTER = "031"
GOLDEN_VALLEY = "033"
GRAND_FORKS = "035"
GRANT = "037"
GRIGGS = "039"
HETTINGER = "041"
KIDDER = "043"
LAMOURE = "045"
LOGAN = "047"
MCHENRY = "049"
MCINTOSH = "051"
MCKENZIE = "053"
MCLEAN = "055"
MERCER = "057"
MORTON = "059"
MOUNTRAIL = "061"
NELSON = "063"
OLIVER = "065"
PEMBINA = "067"
PIERCE = "069"
RAMSEY = "071"
RANSOM = "073"
RENVILLE = "075"
RICHLAND = "077"
ROLETTE = "079"
SARGENT = "081"
SHERIDAN = "083"
SIOUX = "085"
SLOPE = "087"
STARK = "089"
STEELE = "091"
STUTSMAN = "093"
TOWNER = "095"
TRAILL = "097"
WALSH = "099"
WARD = "101"
WELLS = "103"
WILLIAMS = "105"



# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Arkansas."""


ARKANSAS = "001"
ASHLEY = "003"
BAXTER = "005"
BENTON = "007"
BOONE = "009"
BRADLEY = "011"
CALHOUN = "013"
CARROLL = "015"
CHICOT = "017"
CLARK = "019"
CLAY = "021"
CLEBURNE = "023"
CLEVELAND = "025"
COLUMBIA = "027"
CONWAY = "029"
CRAIGHEAD = "031"
CRAWFORD = "033"
CRITTENDEN = "035"
CROSS = "037"
DALLAS = "039"
DESHA = "041"
DREW = "043"
FAULKNER = "045"
FRANKLIN = "047"
FULTON = "049"
GARLAND = "051"
GRANT = "053"
GREENE = "055"
HEMPSTEAD = "057"
HOT_SPRING = "059"
HOWARD = "061"
INDEPENDENCE = "063"
IZARD = "065"
JACKSON = "067"
JEFFERSON = "069"
JOHNSON = "071"
LAFAYETTE = "073"
LAWRENCE = "075"
LEE = "077"
LINCOLN = "079"
LITTLE_RIVER = "081"
LOGAN = "083"
LONOKE = "085"
MADISON = "087"
MARION = "089"
MILLER = "091"
MISSISSIPPI = "093"
MONROE = "095"
MONTGOMERY = "097"
NEVADA = "099"
NEWTON = "101"
OUACHITA = "103"
PERRY = "105"
PHILLIPS = "107"
PIKE = "109"
POINSETT = "111"
POLK = "113"
POPE = "115"
PRAIRIE = "117"
PULASKI = "119"
RANDOLPH = "121"
SALINE = "125"
SCOTT = "127"
SEARCY = "129"
SEBASTIAN = "131"
SEVIER = "133"
SHARP = "135"
ST_FRANCIS = "123"
STONE = "137"
UNION = "139"
VAN_BUREN = "141"
WASHINGTON = "143"
WHITE = "145"
WOODRUFF = "147"
YELL = "149"



# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Kansas."""


ALLEN = "001"
ANDERSON = "003"
ATCHISON = "005"
BARBER = "007"
BARTON = "009"
BOURBON = "011"
BROWN = "013"
BUTLER = "015"
CHASE = "017"
CHAUTAUQUA = "019"
CHEROKEE = "021"
CHEYENNE = "023"
CLARK = "025"
CLAY = "027"
CLOUD = "029"
COFFEY = "031"
COMANCHE = "033"
COWLEY = "035"
CRAWFORD = "037"
DECATUR = "039"
DICKINSON = "041"
DONIPHAN = "043"
DOUGLAS = "045"
EDWARDS = "047"
ELK = "049"
ELLIS = "051"
ELLSWORTH = "053"
FINNEY = "055"
FORD = "057"
FRANKLIN = "059"
GEARY = "061"
GOVE = "063"
GRAHAM = "065"
GRANT = "067"
GRAY = "069"
GREELEY = "071"
GREENWOOD = "073"
HAMILTON = "075"
HARPER = "077"
HARVEY = "079"
HASKELL = "081"
HODGEMAN = "083"
JACKSON = "085"
JEFFERSON = "087"
JEWELL = "089"
JOHNSON = "091"
KEARNY = "093"
KINGMAN = "095"
KIOWA = "097"
LABETTE = "099"
LANE = "101"
LEAVENWORTH = "103"
LINCOLN = "105"
LINN = "107"
LOGAN = "109"
LYON = "111"
MARION = "115"
MARSHALL = "117"
MCPHERSON = "113"
MEADE = "119"
MIAMI = "121"
MITCHELL = "123"
MONTGOMERY = "125"
MORRIS = "127"
MORTON = "129"
NEMAHA = "131"
NEOSHO = "133"
NESS = "135"
NORTON = "137"
OSAGE = "139"
OSBORNE = "141"
OTTAWA = "143"
PAWNEE = "145"
PHILLIPS = "147"
POTTAWATOMIE = "149"
PRATT = "151"
RAWLINS = "153"
RENO = "155"
REPUBLIC = "157"
RICE = "159"
RILEY = "161"
ROOKS = "163"
RUSH = "165"
RUSSELL = "167"
SALINE = "169"
SCOTT = "171"
SEDGWICK = "173"
SEWARD = "175"
SHAWNEE = "177"
SHERIDAN = "179"
SHERMAN = "181"
SMITH = "183"
STAFFORD = "185"
STANTON = "187"
STEVENS = "189"
SUMNER = "191"
THOMAS = "193"
TREGO = "195"
WABAUNSEE = "197"
WALLACE = "199"
WASHINGTON = "201"
WICHITA = "203"
WILSON = "205"
WOODSON = "207"
WYANDOTTE = "209"



# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Wyoming."""


AFTON_TOWN = "00245"
ALBANY_CDP = "00680"
ALBIN_TOWN = "00825"
ALCOVA_CDP = "01115"
ALPINE_NORTHEAST_CDP = "01888"
ALPINE_NORTHWEST_CDP = "01936"
ALPINE_TOWN = "01695"
ALTA_CDP = "01985"
ANTELOPE_HILLS_CDP = "02877"
ARAPAHOE_CDP = "03000"
ARLINGTON_CDP = "03245"
ARROWHEAD_SPRINGS_CDP = "03652"
ARVADA_CDP = "03725"
ATLANTIC_CITY_CDP = "04015"
AUBURN_CDP = "04160"
BAGGS_TOWN = "04740"
BAIROIL_TOWN = "04885"
BAR_NUNN_TOWN = "05245"
BASIN_TOWN = "05320"
BEAR_RIVER_TOWN = "05625"
BEDFORD_CDP = "06045"
BESSEMER_BEND_CDP = "06407"
BEULAH_CDP = "06480"
BIG_HORN_CDP = "06770"
BIG_PINEY_TOWN = "07060"
BONDURANT_CDP = "08365"
BOULDER_CDP = "09235"
BOULDER_FLATS_CDP = "09307"
BROOKHURST_CDP = "10175"
BUFFALO_CITY = "10685"
BURLINGTON_TOWN = "11120"
BURNS_TOWN = "11265"
BYRON_TOWN = "11700"
CARPENTER_CDP = "12860"
CARTER_CDP = "13005"
CASPER_MOUNTAIN_CDP = "13222"
CASPER_CITY = "13150"
CENTENNIAL_CDP = "13440"
CHEYENNE_CITY = "13900"
CHUGCREEK_CDP = "14097"
CHUGWATER_TOWN = "14165"
CLEARMONT_TOWN = "15325"
CLEARVIEW_ACRES_CDP = "15400"
CODY_CITY = "15760"
COKEVILLE_TOWN = "15905"
CORA_CDP = "17210"
COWLEY_TOWN = "17645"
CROWHEART_CDP = "18225"
DANIEL_CDP = "18950"
DAYTON_TOWN = "19385"
DEAVER_TOWN = "19530"
DIAMONDVILLE_TOWN = "20110"
DIXON_TOWN = "20690"
DOUGLAS_CITY = "21125"
DUBOIS_TOWN = "21415"
EAST_THERMOPOLIS_TOWN = "22720"
EDEN_CDP = "23010"
EDGERTON_TOWN = "23155"
EL_RANCHO_CDP = "24350"
ELK_MOUNTAIN_TOWN = "24025"
ENCAMPMENT_TOWN = "24750"
ESTERBROOK_CDP = "25185"
ETHETE_CDP = "25330"
ETNA_CDP = "25475"
EVANSTON_CITY = "25620"
EVANSVILLE_TOWN = "25765"
FAIRVIEW_CDP = "25910"
FARSON_CDP = "26055"
FONTENELLE_CDP = "27650"
FORT_BRIDGER_CDP = "27940"
FORT_LARAMIE_TOWN = "28230"
FORT_WASHAKIE_CDP = "28665"
FOX_FARM_COLLEGE_CDP = "29300"
FOX_PARK_CDP = "29400"
FRANNIE_TOWN = "29825"
FREEDOM_CDP = "30115"
GARLAND_CDP = "30985"
GILLETTE_CITY = "31855"
GLENDO_TOWN = "32290"
GLENROCK_TOWN = "32435"
GRANGER_TOWN = "32870"
GREEN_RIVER_CITY = "33740"
GREYBULL_TOWN = "33885"
GROVER_CDP = "34030"
GUERNSEY_TOWN = "34320"
HANNA_TOWN = "35335"
HARTRANDT_CDP = "35552"
HARTVILLE_TOWN = "35625"
HAWK_SPRINGS_CDP = "36060"
HILL_VIEW_HEIGHTS_CDP = "37727"
HILLSDALE_CDP = "37510"
HOBACK_CDP = "37945"
HOMA_HILLS_CDP = "38307"
HUDSON_TOWN = "38960"
HULETT_TOWN = "39105"
HUNTLEY_CDP = "39250"
HYATTVILLE_CDP = "39395"
JACKSON_TOWN = "40120"
JAMES_TOWN_CDP = "40265"
JEFFREY_CITY_CDP = "40555"
JOHNSTOWN_CDP = "40945"
KAYCEE_TOWN = "41353"
KELLY_CDP = "41860"
KEMMERER_CITY = "42005"
KIRBY_TOWN = "42730"
LA_BARGE_TOWN = "43455"
LAGRANGE_TOWN = "43745"
LAKEVIEW_NORTH_CDP = "44252"
LANCE_CREEK_CDP = "44615"
LANDER_CITY = "44760"
LARAMIE_CITY = "45050"
LINGLE_TOWN = "46790"
LITTLE_AMERICA_CDP = "46935"
LONETREE_CDP = "47370"
LOST_SPRINGS_TOWN = "47805"
LOVELL_TOWN = "47950"
LUCERNE_CDP = "48240"
LUSK_TOWN = "48530"
LYMAN_TOWN = "48675"
MAMMOTH_CDP = "49775"
MANDERSON_TOWN = "49980"
MANVILLE_TOWN = "50270"
MARBLETON_TOWN = "50415"
MCKINNON_CDP = "49400"
MEADOW_ACRES_CDP = "51285"
MEDICINE_BOW_TOWN = "51575"
MEETEETSE_TOWN = "51720"
MIDWEST_TOWN = "52445"
MILLS_TOWN = "53460"
MOORCROFT_TOWN = "54185"
MOOSE_WILSON_ROAD_CDP = "54402"
MOUNTAIN_VIEW_CDP = "55200"
MOUNTAIN_VIEW_TOWN = "55345"
NEWCASTLE_CITY = "56215"
NORDIC_CDP = "56520"
NORTH_ROCK_SPRINGS_CDP = "56700"
OAKLEY_CDP = "57375"
OPAL_TOWN = "57810"
ORIN_CDP = "58100"
OSAGE_CDP = "58680"
OSMOND_CDP = "58970"
OWL_CREEK_CDP = "59332"
PARKMAN_CDP = "59985"
PAVILLION_TOWN = "60130"
PINE_BLUFFS_TOWN = "61435"
PINE_HAVEN_TOWN = "61610"
PINEDALE_TOWN = "61580"
POINT_OF_ROCKS_CDP = "62160"
POWDER_HORN_CDP = "62269"
POWDER_RIVER_CDP = "62305"
POWELL_CITY = "62450"
PURPLE_SAGE_CDP = "62812"
RAFTER_J_RANCH_CDP = "63100"
RALSTON_CDP = "63465"
RANCHESTER_TOWN = "63755"
RANCHETTES_CDP = "63800"
RAWLINS_CITY = "63900"
RED_BUTTE_CDP = "64400"
RELIANCE_CDP = "65060"
RIVERSIDE_TOWN = "66075"
RIVERTON_CITY = "66220"
ROBERTSON_CDP = "66655"
ROCK_RIVER_TOWN = "67090"
ROCK_SPRINGS_CITY = "67235"
ROLLING_HILLS_TOWN = "67440"
RYAN_PARK_CDP = "67670"
SARATOGA_TOWN = "68685"
SHELL_CDP = "69700"
SHERIDAN_CITY = "69845"
SHOSHONI_TOWN = "70570"
SINCLAIR_TOWN = "71150"
SLATER_CDP = "71295"
SLEEPY_HOLLOW_CDP = "71350"
SMOOT_CDP = "71440"
SOUTH_GREELEY_CDP = "71800"
SOUTH_PARK_CDP = "71947"
STAR_VALLEY_RANCH_TOWN = "73180"
STORY_CDP = "73615"
SUNDANCE_TOWN = "74195"
SUPERIOR_TOWN = "74775"
TABLE_ROCK_CDP = "75355"
TAYLOR_CDP = "75572"
TEN_SLEEP_TOWN = "75790"
TETON_VILLAGE_CDP = "75935"
THAYNE_TOWN = "76370"
THERMOPOLIS_TOWN = "76515"
TORRINGTON_CITY = "77530"
TURNERVILLE_CDP = "78400"
UPTON_TOWN = "79125"
URIE_CDP = "79270"
VAN_TASSELL_TOWN = "79705"
VETERAN_CDP = "80285"
VISTA_WEST_CDP = "80575"
WAMSUTTER_TOWN = "81300"
WARREN_AFB_CDP = "81640"
WASHAM_CDP = "81703"
WESTVIEW_CIRCLE_CDP = "82967"
WHEATLAND_TOWN = "83040"
WHITING_CDP = "83100"
WILSON_CDP = "83765"
WOODS_LANDING_JELM_CDP = "84852"
WORLAND_CITY = "84925"
WRIGHT_TOWN = "85015"
Y_O_RANCH_CDP = "86737"
YODER_TOWN = "86665"



# Copyright (c) 2023 Darren Erik Vengroff
"""Places in South Dakota."""


ABERDEEN_CITY = "00100"
AGAR_TOWN = "00460"
AGENCY_VILLAGE_CDP = "00520"
AKASKA_TOWN = "00540"
ALBEE_TOWN = "00620"
ALCESTER_CITY = "00700"
ALEXANDRIA_CITY = "00820"
ALLEN_CDP = "00900"
ALPENA_TOWN = "01020"
ALTAMONT_TOWN = "01140"
ANDERSON_CDP = "01450"
ANDOVER_TOWN = "01500"
ANGOSTURA_CDP = "01560"
ANTELOPE_CDP = "01740"
ARDMORE_CDP = "01980"
ARLINGTON_CITY = "02180"
ARMOUR_CITY = "02260"
ARTAS_TOWN = "02340"
ARTESIAN_TOWN = "02380"
ASHLAND_HEIGHTS_CDP = "02530"
ASHTON_CITY = "02540"
ASTORIA_TOWN = "02580"
AURORA_CENTER_CDP = "02860"
AURORA_TOWN = "02780"
AVON_CITY = "02900"
BADGER_TOWN = "03060"
BALTIC_CITY = "03380"
BANCROFT_TOWN = "03420"
BATESLAND_TOWN = "03860"
BATH_CDP = "03900"
BATH_CORNER_CDP = "03960"
BELLE_FOURCHE_CITY = "04380"
BELVIDERE_TOWN = "04620"
BERESFORD_CITY = "04980"
BIG_STONE_CITY_CITY = "05540"
BIJOU_HILLS_CDP = "05580"
BISON_TOWN = "05620"
BLACKHAWK_CDP = "05780"
BLUCKSBERG_MOUNTAIN_CDP = "06120"
BLUMENGARD_COLONY_CDP = "06140"
BLUNT_CITY = "06180"
BON_HOMME_COLONY_CDP = "06300"
BONESTEEL_CITY = "06220"
BOULDER_CANYON_CDP = "06440"
BOWDLE_CITY = "06540"
BOX_ELDER_CITY = "06620"
BRADLEY_TOWN = "06660"
BRANDON_CITY = "06840"
BRANDT_TOWN = "06940"
BRANT_LAKE_SOUTH_CDP = "07044"
BRANT_LAKE_CITY = "07040"
BRENTFORD_TOWN = "07060"
BRENTWOOD_COLONY_CDP = "07068"
BRIDGER_CDP = "07140"
BRIDGEWATER_CITY = "07180"
BRISTOL_CITY = "07300"
BRITTON_CITY = "07380"
BROADLAND_TOWN = "07420"
BROOKINGS_CITY = "07580"
BRUCE_CITY = "07740"
BRYANT_CITY = "08060"
BUFFALO_CHIP_TOWN = "08330"
BUFFALO_GAP_TOWN = "08340"
BUFFALO_TOWN = "08140"
BULLHEAD_CDP = "08460"
BURBANK_CDP = "08500"
BURKE_CITY = "08700"
BUSHNELL_TOWN = "08820"
BUTLER_TOWN = "08860"
CAMERON_COLONY_CDP = "09204"
CAMP_CROOK_TOWN = "09260"
CAMROSE_COLONY_CDP = "09278"
CANISTOTA_CITY = "09300"
CANOVA_TOWN = "09420"
CANTON_CITY = "09500"
CAPUTA_CDP = "09780"
CARTHAGE_CITY = "10220"
CASTLEWOOD_CITY = "10500"
CAVOUR_TOWN = "10620"
CEDAR_GROVE_COLONY_CDP = "10835"
CENTERVILLE_CITY = "11060"
CENTRAL_CITY_CITY = "11140"
CHAMBERLAIN_CITY = "11220"
CHANCELLOR_TOWN = "11380"
CHELSEA_TOWN = "11500"
CHERRY_CREEK_CDP = "11540"
CHESTER_CDP = "11660"
CLAIRE_CITY_TOWN = "12020"
CLAREMONT_COLONY_CDP = "12148"
CLAREMONT_TOWN = "12100"
CLARK_COLONY_CDP = "12340"
CLARK_CITY = "12180"
CLEAR_LAKE_CDP = "12640"
CLEAR_LAKE_CITY = "12540"
CLEARFIELD_COLONY_CDP = "12508"
CLOVERLEAF_COLONY_CDP = "13010"
COLLINS_COLONY_CDP = "13188"
COLMAN_CITY = "13220"
COLOME_CITY = "13300"
COLONIAL_PINE_HILLS_CDP = "13355"
COLTON_CITY = "13380"
COLUMBIA_CITY = "13420"
CONDE_CITY = "13700"
CORN_CREEK_CDP = "13840"
CORONA_TOWN = "13940"
CORSICA_CITY = "13980"
COTTONWOOD_TOWN = "14220"
COW_CREEK_CDP = "14320"
CRESBARD_TOWN = "14580"
CROCKER_CDP = "14660"
CROOK_CITY_CDP = "14680"
CROOKS_CITY = "14740"
CUSTER_CITY = "15140"
DAKOTA_DUNES_CDP = "15256"
DALLAS_TOWN = "15300"
DANTE_TOWN = "15420"
DAVIS_TOWN = "15540"
DE_SMET_CITY = "16260"
DEADWOOD_CITY = "15700"
DEERFIELD_COLONY_CDP = "15774"
DELL_RAPIDS_CITY = "15980"
DELMONT_CITY = "16060"
DIMOCK_TOWN = "16620"
DOLAND_CITY = "16820"
DOLTON_TOWN = "16860"
DRAPER_TOWN = "17020"
DUDLEY_CDP = "17215"
DUPREE_CITY = "17420"
EAGLE_BUTTE_CITY = "17620"
EDEN_TOWN = "18180"
EDGEMONT_CITY = "18300"
EGAN_CITY = "18460"
ELK_POINT_CITY = "18620"
ELKTON_CITY = "18700"
EMERY_CITY = "19420"
ENEMY_SWIM_CDP = "19556"
ERWIN_TOWN = "19860"
ESTELLINE_CITY = "19980"
ETHAN_TOWN = "20060"
EUREKA_CITY = "20180"
EVERGREEN_COLONY_CDP = "20208"
FAIRBURN_TOWN = "20340"
FAIRFAX_TOWN = "20380"
FAIRVIEW_TOWN = "20780"
FAITH_CITY = "20980"
FARMER_TOWN = "21060"
FAULKTON_CITY = "21260"
FEDORA_CDP = "21340"
FERNEY_CDP = "21380"
FLANDREAU_CITY = "21540"
FLORENCE_TOWN = "21820"
FORDHAM_COLONY_CDP = "22070"
FORESTBURG_CDP = "22100"
FORT_PIERRE_CITY = "22260"
FORT_THOMPSON_CDP = "22340"
FRANKFORT_CITY = "22580"
FREDERICK_TOWN = "22860"
FREEMAN_CITY = "23020"
FRUITDALE_TOWN = "23140"
FULTON_TOWN = "23220"
GANN_VALLEY_CDP = "23421"
GARDEN_CITY_TOWN = "23460"
GARRETSON_CITY = "23820"
GARY_CITY = "23860"
GAYVILLE_TOWN = "23900"
GEDDES_CITY = "23980"
GETTYSBURG_CITY = "24260"
GLENDALE_COLONY_CDP = "24540"
GLENHAM_TOWN = "24620"
GOLDEN_VIEW_COLONY_CDP = "24760"
GOODWIN_TOWN = "24820"
GRACEVILLE_COLONY_CDP = "25020"
GRASS_RANCH_COLONY_CDP = "25743"
GRASSLAND_COLONY_CDP = "25741"
GREEN_GRASS_CDP = "25900"
GREEN_VALLEY_CDP = "26035"
GREENWOOD_COLONY_CDP = "26150"
GREGORY_CITY = "26180"
GRENVILLE_TOWN = "26220"
GROTON_CITY = "26340"
HAMILL_CDP = "26660"
HARRISBURG_CITY = "27260"
HARRISON_CDP = "27300"
HARROLD_TOWN = "27420"
HARTFORD_CITY = "27540"
HAYTI_TOWN = "27820"
HAZEL_TOWN = "27940"
HECLA_CITY = "27980"
HENRY_TOWN = "28140"
HERMOSA_TOWN = "28300"
HERREID_CITY = "28340"
HERRICK_TOWN = "28420"
HETLAND_TOWN = "28460"
HIGHMORE_CITY = "28980"
HILL_CITY_CITY = "29100"
HILLCREST_COLONY_CDP = "29116"
HILLSIDE_COLONY_CDP = "29300"
HILLSVIEW_TOWN = "29340"
HITCHCOCK_TOWN = "29500"
HORSE_CREEK_CDP = "30056"
HOSMER_CITY = "30140"
HOT_SPRINGS_CITY = "30220"
HOVEN_TOWN = "30300"
HOWARD_CITY = "30460"
HUDSON_TOWN = "30740"
HUMBOLDT_TOWN = "30900"
HURLEY_CITY = "30980"
HURON_COLONY_CDP = "31140"
HURON_CITY = "31060"
HUTTERVILLE_COLONY_CDP = "31196"
IDEAL_CDP = "31220"
INTERIOR_TOWN = "31620"
IPSWICH_CITY = "31860"
IRENE_CITY = "31940"
IROQUOIS_CITY = "32020"
ISABEL_TOWN = "32140"
JAMESVILLE_COLONY_CDP = "32388"
JAVA_TOWN = "32460"
JEFFERSON_CITY = "32700"
JOHNSON_SIDING_CDP = "32820"
KADOKA_CITY = "33180"
KAYLOR_CDP = "33380"
KENEL_CDP = "33540"
KENNEBEC_TOWN = "33580"
KEYSTONE_TOWN = "33820"
KIDDER_CDP = "33900"
KIMBALL_CITY = "33980"
KRANZBURG_TOWN = "34340"
KYLE_CDP = "34460"
LA_BOLT_TOWN = "34540"
LA_PLANT_CDP = "35940"
LAKE_ANDES_CITY = "35100"
LAKE_CITY_TOWN = "35220"
LAKE_MADISON_CDP = "35430"
LAKE_NORDEN_CITY = "35460"
LAKE_POINSETT_CDP = "35480"
LAKE_PRESTON_CITY = "35500"
LAKEVIEW_COLONY_CDP = "35671"
LANE_TOWN = "35780"
LANGFORD_TOWN = "35820"
LANTRY_CDP = "35900"
LEAD_CITY = "36220"
LEBANON_TOWN = "36260"
LEMMON_CITY = "36340"
LENNOX_CITY = "36380"
LEOLA_CITY = "36460"
LESTERVILLE_TOWN = "36540"
LETCHER_TOWN = "36620"
LITTLE_EAGLE_CDP = "37900"
LONG_HOLLOW_CDP = "38760"
LONG_LAKE_COLONY_CDP = "38900"
LONG_LAKE_TOWN = "38860"
LOOMIS_CDP = "39020"
LOWER_BRULE_CDP = "39180"
LOWRY_TOWN = "39260"
LYONS_CDP = "39740"
MADISON_CITY = "40220"
MANDERSON_WHITE_HORSE_CREEK_CDP = "40550"
MANSFIELD_CDP = "40580"
MARION_CITY = "40860"
MARTIN_CITY = "41100"
MARTY_CDP = "41180"
MARVIN_TOWN = "41220"
MAVERICK_JUNCTION_CDP = "41398"
MAXWELL_COLONY_CDP = "41420"
MAYFIELD_COLONY_CDP = "41548"
MCINTOSH_CITY = "39940"
MCLAUGHLIN_CITY = "40020"
MEADOW_VIEW_ADDITION_CDP = "41680"
MECKLING_CDP = "41700"
MELLETTE_CITY = "41860"
MENNO_CITY = "41980"
MIDLAND_TOWN = "42140"
MILBANK_CITY = "42260"
MILLBROOK_COLONY_CDP = "42440"
MILLER_CITY = "42460"
MILLERDALE_COLONY_CDP = "42579"
MILLTOWN_CDP = "42620"
MINA_CDP = "42700"
MISSION_HILL_TOWN = "42980"
MISSION_CITY = "42940"
MITCHELL_CITY = "43100"
MOBRIDGE_CITY = "43180"
MONROE_TOWN = "43380"
MONTROSE_CITY = "43500"
MORNINGSIDE_CDP = "43780"
MORRISTOWN_TOWN = "43860"
MOUND_CITY_TOWN = "44020"
MOUNT_VERNON_CITY = "44100"
MOUNTAIN_PLAINS_CDP = "44032"
MURDO_CITY = "44260"
NAPLES_TOWN = "44620"
NEW_EFFINGTON_TOWN = "44820"
NEW_ELM_SPRING_COLONY_CDP = "44900"
NEW_HOLLAND_CDP = "44940"
NEW_UNDERWOOD_CITY = "45060"
NEW_WITTEN_TOWN = "45100"
NEWDALE_COLONY_CDP = "44800"
NEWELL_CITY = "44860"
NEWPORT_COLONY_CDP = "45024"
NISLAND_TOWN = "45180"
NORFELD_COLONY_CDP = "45390"
NORRIS_CDP = "45420"
NORTH_EAGLE_BUTTE_CDP = "45548"
NORTH_SIOUX_CITY_CITY = "45700"
NORTH_SPEARFISH_CDP = "45715"
NORTHVILLE_TOWN = "45740"
NUNDA_TOWN = "46060"
OACOMA_TOWN = "46180"
OAHE_ACRES_CDP = "46240"
OAK_LANE_COLONY_CDP = "46388"
OELRICHS_TOWN = "46500"
OGLALA_CDP = "46540"
OKATON_CDP = "46620"
OKREEK_CDP = "46660"
OLA_CDP = "46700"
OLD_ELM_SPRING_COLONY_CDP = "46770"
OLDHAM_CITY = "46780"
OLIVET_TOWN = "46900"
ONAKA_TOWN = "46980"
ONIDA_CITY = "47180"
ORAL_CDP = "47340"
ORIENT_TOWN = "47460"
ORLAND_COLONY_CDP = "47588"
ORTLEY_TOWN = "47660"
PARKER_CITY = "48380"
PARKSTON_CITY = "48460"
PARMELEE_CDP = "48500"
PEARL_CREEK_COLONY_CDP = "48820"
PEEVER_FLATS_CDP = "48948"
PEEVER_TOWN = "48940"
PEMBROOK_COLONY_CDP = "49028"
PHILIP_CITY = "49300"
PICKSTOWN_TOWN = "49460"
PIEDMONT_CITY = "49500"
PIERPONT_TOWN = "49540"
PIERRE_CITY = "49600"
PINE_LAKES_ADDITION_CDP = "49640"
PINE_RIDGE_CDP = "49660"
PLAINVIEW_COLONY_CDP = "49980"
PLANKINTON_CITY = "50020"
PLATTE_COLONY_CDP = "50310"
PLATTE_CITY = "50260"
PLEASANT_VALLEY_COLONY_CDP = "50988"
POINSETT_COLONY_CDP = "51220"
POLLOCK_TOWN = "51260"
PORCUPINE_CDP = "51340"
PRAIRIE_CITY_CDP = "51660"
PRAIRIEWOOD_VILLAGE_CDP = "51724"
PRESHO_CITY = "51820"
PRINGLE_TOWN = "51940"
PROVO_CDP = "52140"
PUKWANA_TOWN = "52220"
QUINN_TOWN = "52500"
RAMONA_TOWN = "52860"
RAPID_CITY_CITY = "52980"
RAPID_VALLEY_CDP = "53007"
RAVINIA_TOWN = "53220"
RAYMOND_TOWN = "53260"
REDFIELD_CITY = "53460"
REE_HEIGHTS_TOWN = "53940"
RELIANCE_TOWN = "54020"
RENNER_CORNER_CDP = "54145"
REVILLO_TOWN = "54220"
RICHLAND_CDP = "54750"
RIVERSIDE_COLONY_CDP = "55220"
ROCKHAM_TOWN = "55540"
ROCKPORT_COLONY_CDP = "55620"
ROLLAND_COLONY_CDP = "55684"
ROSCOE_CITY = "55820"
ROSEBUD_CDP = "55940"
ROSEDALE_COLONY_CDP = "56140"
ROSHOLT_TOWN = "56340"
ROSLYN_TOWN = "56380"
ROSWELL_CDP = "56420"
ROWENA_CDP = "56580"
RUNNING_WATER_CDP = "56820"
RUSTIC_ACRES_COLONY_CDP = "56964"
SALEM_CITY = "57340"
SCOTLAND_CITY = "57940"
SELBY_CITY = "58140"
SENECA_TOWN = "58180"
SHAMROCK_COLONY_CDP = "58310"
SHANNON_COLONY_CDP = "58332"
SHERMAN_TOWN = "58580"
SHINDLER_CDP = "58590"
SICANGU_VILLAGE_CDP = "58680"
SILVER_LAKE_COLONY_CDP = "58868"
SINAI_TOWN = "58900"
SIOUX_FALLS_CITY = "59020"
SISSETON_CITY = "59260"
SMITHWICK_CDP = "59620"
SOLDIER_CREEK_CDP = "59700"
SOUTH_SHORE_TOWN = "59940"
SPEARFISH_CITY = "60020"
SPENCER_CITY = "60060"
SPINK_COLONY_CDP = "60180"
SPRING_CREEK_CDP = "60500"
SPRING_CREEK_COLONY_CDP = "60540"
SPRING_LAKE_COLONY_CDP = "60958"
SPRING_VALLEY_COLONY_CDP = "61180"
SPRINGFIELD_CITY = "60660"
ST_CHARLES_CDP = "57060"
ST_FRANCIS_TOWN = "57140"
ST_LAWRENCE_TOWN = "57180"
ST_ONGE_CDP = "57260"
STEPHAN_CDP = "61580"
STICKNEY_TOWN = "61700"
STOCKHOLM_TOWN = "61740"
STORLA_CDP = "61940"
STRANDBURG_TOWN = "61980"
STRATFORD_TOWN = "62020"
STURGIS_CITY = "62100"
SUMMERSET_CITY = "62155"
SUMMIT_TOWN = "62220"
SUNSET_COLONY_CDP = "62434"
SWIFT_BIRD_CDP = "62716"
TABOR_TOWN = "62820"
TEA_CITY = "63100"
THUNDERBIRD_COLONY_CDP = "63452"
TIMBER_LAKE_CITY = "63620"
TOLSTOY_TOWN = "63700"
TORONTO_TOWN = "63740"
TRENT_TOWN = "63940"
TRIPP_CITY = "64020"
TSCHETTER_COLONY_CDP = "64260"
TULARE_TOWN = "64300"
TURTON_TOWN = "64540"
TWIN_BROOKS_TOWN = "64700"
TWO_STRIKE_CDP = "64840"
TYNDALL_CITY = "64860"
UPLAND_COLONY_CDP = "65628"
UTICA_TOWN = "65780"
VALE_CDP = "65900"
VALLEY_SPRINGS_CITY = "66260"
VEBLEN_CITY = "66540"
VERDON_TOWN = "66660"
VERMILLION_CITY = "66700"
VIBORG_CITY = "67020"
VIENNA_TOWN = "67220"
VILAS_TOWN = "67340"
VIRGIL_TOWN = "67500"
VIVIAN_CDP = "67620"
VOLGA_CITY = "67700"
VOLIN_TOWN = "67780"
WAGNER_CITY = "68020"
WAKONDA_TOWN = "68100"
WAKPALA_CDP = "68140"
WALL_TOWN = "68380"
WALLACE_TOWN = "68420"
WANBLEE_CDP = "68580"
WARD_TOWN = "68660"
WARNER_TOWN = "68740"
WASTA_TOWN = "69140"
WATERTOWN_CITY = "69300"
WAUBAY_CITY = "69340"
WAVERLY_CDP = "69420"
WEBSTER_CITY = "69780"
WENTWORTH_VILLAGE = "70020"
WESSINGTON_SPRINGS_CITY = "70220"
WESSINGTON_CITY = "70140"
WEST_BRULE_CDP = "70284"
WESTPORT_TOWN = "70540"
WESTWOOD_COLONY_CDP = "70646"
WETONKA_TOWN = "70740"
WHITE_HORSE_CDP = "71150"
WHITE_LAKE_CITY = "71180"
WHITE_RIVER_CITY = "71340"
WHITE_ROCK_COLONY_CDP = "71440"
WHITE_ROCK_TOWN = "71380"
WHITE_CITY = "70940"
WHITEHORSE_CDP = "71140"
WHITEWOOD_CITY = "71580"
WILLOW_LAKE_CITY = "71940"
WILMOT_CITY = "71980"
WINFRED_CDP = "72100"
WINNER_CITY = "72180"
WOLF_CREEK_COLONY_CDP = "72500"
WOLSEY_TOWN = "72540"
WONDERLAND_HOMES_CDP = "72590"
WOOD_TOWN = "72620"
WOONSOCKET_CITY = "72700"
WORTHING_CITY = "72820"
WOUNDED_KNEE_CDP = "72900"
YALE_TOWN = "73020"
YANKTON_CITY = "73060"



# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Indiana."""


ABERDEEN_CDP = "00140"
ABINGTON_CDP = "00154"
ADAMS_CDP = "00352"
ADAMS_LAKE_CDP = "00532"
ADVANCE_TOWN = "00640"
AKRON_TOWN = "00748"
ALAMO_TOWN = "00784"
ALBANY_TOWN = "00802"
ALBION_TOWN = "00820"
ALEXANDRIA_CITY = "00910"
ALFORD_CDP = "00946"
ALFORDSVILLE_TOWN = "00964"
ALTON_TOWN = "01270"
ALTONA_TOWN = "01288"
AMBIA_TOWN = "01342"
AMBOY_TOWN = "01360"
AMERICUS_CDP = "01396"
AMITY_CDP = "01432"
AMO_TOWN = "01450"
ANDERSON_CITY = "01468"
ANDERSONVILLE_CDP = "01594"
ANDREWS_TOWN = "01612"
ANGOLA_CITY = "01666"
ANOKA_CDP = "01738"
ANTIOCH_CDP = "01810"
ARCADIA_TOWN = "01954"
ARCOLA_CDP = "01990"
ARDMORE_CDP = "02026"
ARGOS_TOWN = "02044"
ARLINGTON_CDP = "02116"
ARTHUR_CDP = "02296"
ASHLEY_TOWN = "02458"
ATLANTA_TOWN = "02602"
ATTICA_CITY = "02620"
AUBURN_CITY = "02674"
AURORA_CITY = "02782"
AUSTIN_CITY = "02800"
AVILLA_TOWN = "02872"
AVOCA_CDP = "02890"
AVON_TOWN = "02908"
AZALIA_CDP = "03052"
BAINBRIDGE_TOWN = "03142"
BARBEE_CDP = "03358"
BARGERSVILLE_TOWN = "03394"
BASS_LAKE_CDP = "03610"
BATESVILLE_CITY = "03664"
BATTLE_GROUND_TOWN = "03718"
BEAR_LAKE_CDP = "03898"
BEAVER_DAM_CDP = "04032"
BEDFORD_CITY = "04114"
BEECH_GROVE_CITY = "04204"
BELLEVILLE_CDP = "04456"
BENNETTS_SWITCH_CDP = "04726"
BENTON_CDP = "04780"
BERNE_CITY = "04888"
BETHANY_TOWN = "04978"
BETHEL_VILLAGE_CDP = "05050"
BEVERLY_SHORES_TOWN = "05158"
BICKNELL_CITY = "05176"
BIG_LAKE_CDP = "05230"
BILLTOWN_CDP = "05284"
BIPPUS_CDP = "05338"
BIRDSEYE_TOWN = "05374"
BLAIRSVILLE_CDP = "05644"
BLANFORD_CDP = "05662"
BLOCHER_CDP = "05680"
BLOOMFIELD_TOWN = "05716"
BLOOMING_GROVE_CDP = "05806"
BLOOMINGDALE_TOWN = "05788"
BLOOMINGTON_CITY = "05860"
BLOUNTSVILLE_TOWN = "05896"
BLUE_RIDGE_CDP = "06022"
BLUFFTON_CITY = "06220"
BOGGSTOWN_CDP = "06292"
BOONE_GROVE_CDP = "06598"
BOONVILLE_CITY = "06616"
BORDEN_TOWN = "06634"
BOSTON_TOWN = "06652"
BOSWELL_TOWN = "06706"
BOURBON_TOWN = "06760"
BOWLING_GREEN_CDP = "06832"
BOXLEY_CDP = "06904"
BRAZIL_CITY = "07174"
BREMEN_TOWN = "07318"
BRETZVILLE_CDP = "07426"
BRIDGETON_CDP = "07570"
BRIGHT_CDP = "07624"
BRIMFIELD_CDP = "07678"
BRINGHURST_CDP = "07714"
BRISTOL_TOWN = "07750"
BROOK_TOWN = "07966"
BROOKLYN_TOWN = "08038"
BROOKSBURG_TOWN = "08092"
BROOKSTON_TOWN = "08146"
BROOKVILLE_TOWN = "08182"
BROWNS_CROSSING_CDP = "08434"
BROWNSBURG_TOWN = "08416"
BROWNSTOWN_TOWN = "08470"
BROWNSVILLE_CDP = "08524"
BRUCEVILLE_TOWN = "08578"
BRYANT_TOWN = "08704"
BUCK_CREEK_CDP = "08812"
BUCKSKIN_CDP = "08848"
BUFFALO_CDP = "08992"
BUNKER_HILL_TOWN = "09136"
BURKET_TOWN = "09226"
BURLINGTON_TOWN = "09244"
BURNETT_CDP = "09298"
BURNETTSVILLE_TOWN = "09316"
BURNEY_CDP = "09334"
BURNS_CITY_CDP = "09352"
BURNS_HARBOR_TOWN = "09370"
BURROWS_CDP = "09460"
BUTLER_CITY = "09532"
BUTLERVILLE_CDP = "09622"
CADIZ_TOWN = "09712"
CAMBRIDGE_CITY_TOWN = "09874"
CAMDEN_TOWN = "09910"
CAMPBELLSBURG_TOWN = "10000"
CANAAN_CDP = "10036"
CANNELBURG_TOWN = "10090"
CANNELTON_CITY = "10108"
CANTON_CDP = "10144"
CARBON_TOWN = "10198"
CARLISLE_TOWN = "10270"
CARMEL_CITY = "10342"
CARROLLTON_CDP = "10558"
CARTERSBURG_CDP = "10594"
CARTHAGE_TOWN = "10612"
CASS_CDP = "10774"
CASSVILLE_CDP = "10828"
CATES_CDP = "10900"
CAYUGA_TOWN = "10954"
CEDAR_GROVE_TOWN = "11044"
CEDAR_LAKE_TOWN = "11062"
CELESTINE_CDP = "11134"
CENTENARY_CDP = "11188"
CENTER_CDP = "11404"
CENTER_POINT_TOWN = "11746"
CENTERTON_CDP = "11782"
CENTERVILLE_TOWN = "11836"
CHAIN_O_LAKES_CDP = "11926"
CHALMERS_TOWN = "11944"
CHANDLER_TOWN = "12034"
CHARLESTOWN_CITY = "12124"
CHARLOTTESVILLE_CDP = "12196"
CHESTERFIELD_TOWN = "12376"
CHESTERTON_TOWN = "12412"
CHILI_CDP = "12502"
CHRISNEY_TOWN = "12574"
CHURUBUSCO_TOWN = "12610"
CICERO_TOWN = "12628"
CLARKS_HILL_TOWN = "12898"
CLARKSBURG_CDP = "12880"
CLARKSVILLE_TOWN = "12934"
CLAY_CITY_TOWN = "13276"
CLAYPOOL_TOWN = "13312"
CLAYTON_TOWN = "13366"
CLEAR_LAKE_TOWN = "13438"
CLERMONT_TOWN = "13492"
CLIFFORD_TOWN = "13582"
CLINTON_CITY = "13780"
CLOVERDALE_TOWN = "13852"
CLOVERLAND_CDP = "13888"
COAL_CITY_CDP = "13978"
COALMONT_CDP = "14032"
COATESVILLE_TOWN = "14050"
COESSE_CDP = "14104"
COLBURN_CDP = "14176"
COLFAX_TOWN = "14284"
COLUMBIA_CITY_CITY = "14716"
COLUMBUS_CITY = "14734"
COMMISKEY_CDP = "14788"
CONNERSVILLE_CITY = "14932"
CONVERSE_TOWN = "14986"
CORDRY_SWEETWATER_LAKES_CDP = "15115"
CORTLAND_CDP = "15202"
CORUNNA_TOWN = "15220"
CORY_CDP = "15238"
CORYDON_TOWN = "15256"
COUNTRY_CLUB_HEIGHTS_TOWN = "15364"
COUNTRY_SQUIRE_LAKES_CDP = "15409"
COVINGTON_CITY = "15490"
COWAN_CDP = "15526"
CRAIGVILLE_CDP = "15616"
CRANDALL_TOWN = "15634"
CRANE_TOWN = "15652"
CRAWFORDSVILLE_CITY = "15742"
CREE_LAKE_CDP = "15778"
CROMWELL_TOWN = "15994"
CROSS_PLAINS_CDP = "16030"
CROTHERSVILLE_TOWN = "16084"
CROWN_POINT_CITY = "16138"
CROWS_NEST_TOWN = "16156"
CULVER_TOWN = "16300"
CUMBERLAND_TOWN = "16336"
CUTLER_CDP = "16480"
CYNTHIANA_TOWN = "16534"
DALE_TOWN = "16624"
DALEVILLE_TOWN = "16642"
DANA_TOWN = "16732"
DANVILLE_TOWN = "16804"
DARLINGTON_TOWN = "16840"
DARMSTADT_TOWN = "16858"
DAYTON_TOWN = "17002"
DE_MOTTE_TOWN = "17722"
DECATUR_CITY = "17074"
DECKER_TOWN = "17110"
DEER_CREEK_CDP = "17245"
DELAWARE_CDP = "17506"
DELPHI_CITY = "17614"
DENVER_TOWN = "17776"
DEPAUW_CDP = "17794"
DEPUTY_CDP = "17812"
DILLSBORO_TOWN = "18190"
DONALDSON_CDP = "18388"
DOVER_HILL_CDP = "18550"
DRESSER_CDP = "18658"
DUBLIN_TOWN = "18766"
DUBOIS_CDP = "18784"
DUGGER_TOWN = "18892"
DUNE_ACRES_TOWN = "18982"
DUNELAND_BEACH_CDP = "19000"
DUNKIRK_CITY = "19054"
DUNLAP_CDP = "19072"
DUNREITH_TOWN = "19162"
DUPONT_TOWN = "19180"
DYER_TOWN = "19270"
EARL_PARK_TOWN = "19450"
EAST_CHICAGO_CITY = "19486"
EAST_ENTERPRISE_CDP = "19576"
EAST_GERMANTOWN_TOWN = "19756"
EAST_OOLITIC_CDP = "19936"
EATON_TOWN = "20080"
ECKERTY_CDP = "20134"
ECONOMY_TOWN = "20152"
EDEN_CDP = "20188"
EDGEWOOD_TOWN = "20332"
EDINBURGH_TOWN = "20404"
EDWARDSPORT_TOWN = "20458"
ELBERFELD_TOWN = "20638"
ELIZABETH_TOWN = "20674"
ELIZABETHTOWN_TOWN = "20692"
ELIZAVILLE_CDP = "20710"
ELKHART_CITY = "20728"
ELLETTSVILLE_TOWN = "20800"
ELNORA_TOWN = "20998"
ELROD_CDP = "21034"
ELWOOD_CITY = "21070"
EMINENCE_CDP = "21106"
EMISON_CDP = "21124"
ENCHANTED_HILLS_CDP = "21178"
ENGLISH_TOWN = "21214"
ETNA_GREEN_TOWN = "21502"
EUGENE_CDP = "21538"
EVANSVILLE_CITY = "22000"
EVERTON_CDP = "22072"
FAIR_OAKS_CDP = "22468"
FAIRBANKS_CDP = "22180"
FAIRLAND_TOWN = "22396"
FAIRMOUNT_TOWN = "22432"
FAIRVIEW_CDP = "22540"
FAIRVIEW_PARK_TOWN = "22576"
FARMERSBURG_TOWN = "22738"
FARMLAND_TOWN = "22792"
FERDINAND_TOWN = "22990"
FILLMORE_TOWN = "23188"
FISH_LAKE_CDP = "23386"
FISHERS_CITY = "23278"
FISHERSBURG_CDP = "23296"
FLAT_ROCK_CDP = "23566"
FLORA_TOWN = "23692"
FLORENCE_CDP = "23728"
FLOYDS_KNOBS_CDP = "23800"
FOLSOMVILLE_CDP = "23836"
FONTANET_CDP = "23854"
FOREST_CDP = "23926"
FORT_BRANCH_TOWN = "24250"
FORT_WAYNE_CITY = "25000"
FORTVILLE_TOWN = "24286"
FOSTER_CDP = "25054"
FOUNTAIN_CITY_TOWN = "25090"
FOUNTAINTOWN_CDP = "25162"
FOWLER_TOWN = "25180"
FOWLERTON_TOWN = "25198"
FOXCLIFF_ESTATES_CDP = "25212"
FRANCESVILLE_TOWN = "25288"
FRANCISCO_TOWN = "25306"
FRANKFORT_CITY = "25324"
FRANKLIN_CITY = "25450"
FRANKTON_TOWN = "25702"
FREDERICKSBURG_CDP = "25720"
FREELANDVILLE_CDP = "25810"
FREETOWN_CDP = "25864"
FREMONT_TOWN = "25882"
FRENCH_LICK_TOWN = "25972"
FULTON_TOWN = "26152"
GALENA_CDP = "26206"
GALVESTON_TOWN = "26242"
GARRETT_CITY = "26386"
GARY_CITY = "27000"
GAS_CITY_CITY = "27054"
GASTON_TOWN = "27072"
GENEVA_CDP = "27252"
GENEVA_TOWN = "27216"
GENTRYVILLE_TOWN = "27270"
GEORGETOWN_TOWN = "27324"
GILMER_PARK_CDP = "27720"
GLENWOOD_TOWN = "28062"
GLEZEN_CDP = "28116"
GOLDSMITH_CDP = "28296"
GOODLAND_TOWN = "28332"
GOSHEN_CITY = "28386"
GOSPORT_TOWN = "28440"
GRABILL_TOWN = "28494"
GRAMMER_CDP = "28620"
GRANDVIEW_LAKE_CDP = "28728"
GRANDVIEW_TOWN = "28692"
GRANGER_CDP = "28800"
GRANTSBURG_CDP = "28908"
GRAYFORD_CDP = "29070"
GRAYSVILLE_CDP = "29106"
GREEN_HILL_CDP = "29592"
GREENCASTLE_CITY = "29358"
GREENDALE_CITY = "29448"
GREENFIELD_CITY = "29520"
GREENS_FORK_TOWN = "29754"
GREENSBORO_TOWN = "29682"
GREENSBURG_CITY = "29718"
GREENTOWN_TOWN = "29772"
GREENVILLE_TOWN = "29844"
GREENWOOD_CITY = "29898"
GRIFFIN_TOWN = "30024"
GRIFFITH_TOWN = "30042"
GRISSOM_AFB_CDP = "30060"
GROVELAND_CDP = "30114"
GROVERTON_CDP = "30150"
GWYNNEVILLE_CDP = "30294"
HAGERSTOWN_TOWN = "30402"
HAMBURG_CDP = "30564"
HAMILTON_TOWN = "30594"
HAMLET_TOWN = "30708"
HAMMOND_CITY = "31000"
HANNA_CDP = "31180"
HANOVER_TOWN = "31216"
HARDINSBURG_TOWN = "31396"
HARLAN_CDP = "31432"
HARMONY_TOWN = "31486"
HARRISON_LAKE_CDP = "32098"
HARRODSBURG_CDP = "32170"
HARTFORD_CITY_CITY = "32242"
HARTSVILLE_TOWN = "32332"
HARTZ_LAKE_CDP = "32768"
HASHTOWN_CDP = "32422"
HATFIELD_CDP = "32494"
HAUBSTADT_TOWN = "32512"
HAYDEN_CDP = "32584"
HAYSVILLE_CDP = "32638"
HAZLETON_TOWN = "32728"
HEBRON_TOWN = "32818"
HEDRICK_CDP = "32854"
HELMER_CDP = "32926"
HELMSBURG_CDP = "32944"
HELTONVILLE_CDP = "32980"
HEMLOCK_CDP = "32998"
HENRYVILLE_CDP = "33142"
HERBST_CDP = "33178"
HERITAGE_LAKE_CDP = "33187"
HESSEN_CASSEL_CDP = "33214"
HIDDEN_VALLEY_CDP = "33392"
HIGHLAND_CDP = "33484"
HIGHLAND_TOWN = "33466"
HILLISBURG_CDP = "33826"
HILLSBORO_TOWN = "33862"
HILLSDALE_CDP = "33952"
HOAGLAND_CDP = "34096"
HOBART_CITY = "34114"
HOBBS_CDP = "34168"
HOFFMAN_LAKE_CDP = "34186"
HOLIDAY_WOODS_CDP = "34284"
HOLLAND_TOWN = "34294"
HOLTON_TOWN = "34366"
HOMECROFT_TOWN = "34420"
HOMER_CDP = "34456"
HOPE_TOWN = "34744"
HORTONVILLE_CDP = "34816"
HOWE_CDP = "34978"
HUDSON_LAKE_CDP = "35104"
HUDSON_TOWN = "35086"
HUNTERTOWN_TOWN = "35266"
HUNTINGBURG_CITY = "35284"
HUNTINGTON_CITY = "35302"
HURON_CDP = "35392"
HYMERA_TOWN = "35500"
IDAVILLE_CDP = "35536"
INDEPENDENCE_CDP = "35626"
INDIAN_VILLAGE_TOWN = "36306"
INDIANAPOLIS_CITY_BALANCE = "36003"
INGALLS_TOWN = "36342"
IRELAND_CDP = "36468"
JALAPA_CDP = "37674"
JAMESTOWN_TOWN = "37692"
JASONVILLE_CITY = "37764"
JASPER_CITY = "37782"
JEFFERSON_CDP = "37908"
JEFFERSONVILLE_CITY = "38358"
JEROME_CDP = "38484"
JIMMERSON_LAKE_CDP = "38547"
JOHNSON_CDP = "38664"
JONESBORO_CITY = "38862"
JONESVILLE_TOWN = "38916"
JUDAH_CDP = "39042"
JUDSON_CDP = "39078"
JUDYVILLE_CDP = "39096"
KEMPTON_TOWN = "39366"
KENDALLVILLE_CITY = "39402"
KENNARD_TOWN = "39438"
KENT_CDP = "39510"
KENTLAND_TOWN = "39546"
KEWANNA_TOWN = "39618"
KEYSTONE_CDP = "39654"
KIMMELL_CDP = "39744"
KINGMAN_TOWN = "39798"
KINGSBURY_TOWN = "39816"
KINGSFORD_HEIGHTS_TOWN = "39852"
KIRKLIN_TOWN = "39942"
KNIGHTSTOWN_TOWN = "40266"
KNIGHTSVILLE_TOWN = "40302"
KNOX_CITY = "40374"
KOKOMO_CITY = "40392"
KOONTZ_LAKE_CDP = "40464"
KOUTS_TOWN = "40518"
KRAMER_CDP = "40536"
LA_CROSSE_TOWN = "40662"
LA_FONTAINE_TOWN = "40842"
LA_PAZ_TOWN = "42192"
LA_PORTE_CITY = "42246"
LACONIA_TOWN = "40644"
LADOGA_TOWN = "40698"
LAFAYETTE_CITY = "40788"
LAGRANGE_TOWN = "40860"
LAGRO_TOWN = "40896"
LAKE_BRUCE_CDP = "41004"
LAKE_CICOTT_CDP = "41022"
LAKE_DALECARLIA_CDP = "41058"
LAKE_ELIZA_CDP = "41112"
LAKE_EVERETT_CDP = "41130"
LAKE_HOLIDAY_CDP = "41211"
LAKE_HOLIDAY_HIDEAWAY_CDP = "41215"
LAKE_SANTEE_CDP = "41444"
LAKE_STATION_CITY = "41535"
LAKE_VIEW_CDP = "41580"
LAKE_VILLAGE_CDP = "41652"
LAKE_OF_THE_WOODS_CDP = "41400"
LAKES_OF_THE_FOUR_SEASONS_CDP = "41530"
LAKESHORE_RESORT_CDP = "41463"
LAKETON_CDP = "41562"
LAKEVILLE_TOWN = "41670"
LAKEWOOD_CDP = "41706"
LAMB_CDP = "41796"
LANDESS_CDP = "41994"
LANESVILLE_TOWN = "42048"
LAOTTO_CDP = "42138"
LAPEL_TOWN = "42228"
LARWILL_TOWN = "42282"
LAUD_CDP = "42318"
LAUREL_TOWN = "42372"
LAWRENCE_CITY = "42426"
LAWRENCEBURG_CITY = "42462"
LAWRENCEPORT_CDP = "42516"
LEAVENWORTH_TOWN = "42606"
LEBANON_CITY = "42624"
LEESBURG_TOWN = "42678"
LEITERS_FORD_CDP = "42822"
LEO_CEDARVILLE_TOWN = "42861"
LEOPOLD_CDP = "42876"
LETTS_CDP = "42984"
LEWIS_CDP = "43020"
LEWISVILLE_TOWN = "43074"
LIBERTY_CENTER_CDP = "43542"
LIBERTY_MILLS_CDP = "43596"
LIBERTY_TOWN = "43434"
LIBERTYVILLE_CDP = "43632"
LIGONIER_CITY = "43686"
LINCOLN_CDP = "43776"
LINDEN_TOWN = "44082"
LINN_GROVE_CDP = "44154"
LINNSBURG_CDP = "44172"
LINTON_CITY = "44190"
LITTLE_YORK_TOWN = "44370"
LIVONIA_TOWN = "44424"
LIZTON_TOWN = "44442"
LOGANSPORT_CITY = "44658"
LONDON_CDP = "44712"
LONG_BEACH_TOWN = "44784"
LOOGOOTEE_CITY = "44910"
LOSANTVILLE_TOWN = "45000"
LOWELL_TOWN = "45144"
LUCERNE_CDP = "45234"
LYFORD_CDP = "45396"
LYNN_TOWN = "45468"
LYNNVILLE_TOWN = "45486"
LYONS_TOWN = "45504"
MACE_CDP = "45720"
MACKEY_TOWN = "45774"
MACY_TOWN = "45864"
MADISON_CITY = "45990"
MALDEN_CDP = "46296"
MANILLA_CDP = "46422"
MAPLES_CDP = "46566"
MARENGO_TOWN = "46746"
MARIAH_HILL_CDP = "46764"
MARIETTA_CDP = "46782"
MARION_CDP = "47045"
MARION_CITY = "46908"
MARKLE_TOWN = "47160"
MARKLEVILLE_TOWN = "47178"
MARSHALL_TOWN = "47322"
MARSHFIELD_CDP = "47340"
MARTINSBURG_CDP = "47430"
MARTINSVILLE_CITY = "47448"
MATTHEWS_TOWN = "47592"
MAUCKPORT_TOWN = "47628"
MAXWELL_CDP = "47736"
MAYS_CDP = "47826"
MCCORDSVILLE_TOWN = "45648"
MECCA_TOWN = "48132"
MEDARYVILLE_TOWN = "48186"
MEDORA_TOWN = "48240"
MELLOTT_TOWN = "48294"
MELODY_HILL_CDP = "48330"
MEMPHIS_CDP = "48384"
MENTONE_TOWN = "48402"
MERIDIAN_HILLS_TOWN = "48456"
MEROM_TOWN = "48474"
MERRIAM_CDP = "48510"
MERRILLVILLE_TOWN = "48528"
METAMORA_CDP = "48563"
METZ_CDP = "48618"
MEXICO_CDP = "48636"
MIAMI_CDP = "48672"
MICHIANA_SHORES_TOWN = "48744"
MICHIGAN_CITY_CITY = "48798"
MICHIGANTOWN_TOWN = "48816"
MIDDLEBURY_CDP = "48906"
MIDDLEBURY_TOWN = "48924"
MIDDLETOWN_TOWN = "49014"
MIDLAND_CDP = "49086"
MIER_CDP = "49212"
MILAN_TOWN = "49266"
MILFORD_CDP = "49302"
MILFORD_TOWN = "49320"
MILLERSBURG_TOWN = "49536"
MILLGROVE_CDP = "49626"
MILLHOUSEN_TOWN = "49662"
MILLTOWN_TOWN = "49716"
MILLVILLE_CDP = "49734"
MILROY_CDP = "49806"
MILTON_TOWN = "49860"
MINERAL_SPRINGS_CDP = "49892"
MISHAWAKA_CITY = "49932"
MITCHELL_CITY = "49950"
MODOC_TOWN = "50058"
MONGO_CDP = "50094"
MONON_TOWN = "50148"
MONROE_CITY_TOWN = "50526"
MONROE_TOWN = "50202"
MONROEVILLE_TOWN = "50562"
MONROVIA_TOWN = "50580"
MONTEREY_TOWN = "50616"
MONTEZUMA_TOWN = "50652"
MONTGOMERY_TOWN = "50688"
MONTICELLO_CITY = "50760"
MONTMORENCI_CDP = "50778"
MONTPELIER_CITY = "50796"
MOORELAND_TOWN = "50940"
MOORES_HILL_TOWN = "50958"
MOORESVILLE_TOWN = "50976"
MORGANTOWN_TOWN = "51102"
MOROCCO_TOWN = "51138"
MORRIS_CDP = "51174"
MORRISTOWN_TOWN = "51192"
MOUNT_AUBURN_TOWN = "51318"
MOUNT_AYR_TOWN = "51336"
MOUNT_CARMEL_TOWN = "51354"
MOUNT_ETNA_TOWN = "51408"
MOUNT_SUMMIT_TOWN = "51714"
MOUNT_VERNON_CITY = "51732"
MULBERRY_TOWN = "51840"
MUNCIE_CITY = "51876"
MUNSTER_TOWN = "51912"
NAPOLEON_TOWN = "52002"
NAPPANEE_CITY = "52020"
NASHVILLE_TOWN = "52038"
NEEDHAM_CDP = "52146"
NEEDMORE_CDP = "52200"
NEW_ALBANY_CITY = "52326"
NEW_AMSTERDAM_TOWN = "52398"
NEW_CARLISLE_TOWN = "52704"
NEW_CASTLE_CITY = "52740"
NEW_CHICAGO_TOWN = "52776"
NEW_GOSHEN_CDP = "52956"
NEW_HARMONY_TOWN = "52974"
NEW_HAVEN_CITY = "52992"
NEW_LEBANON_CDP = "53118"
NEW_LISBON_CDP = "53154"
NEW_LONDON_CDP = "53190"
NEW_MARION_CDP = "53226"
NEW_MARKET_TOWN = "53262"
NEW_MIDDLETOWN_TOWN = "53298"
NEW_PALESTINE_TOWN = "53352"
NEW_PARIS_CDP = "53370"
NEW_PEKIN_TOWN = "53388"
NEW_POINT_TOWN = "53478"
NEW_RICHMOND_TOWN = "53532"
NEW_ROSS_TOWN = "53550"
NEW_SALISBURY_CDP = "53586"
NEW_TRENTON_CDP = "53712"
NEW_WASHINGTON_CDP = "53820"
NEW_WHITELAND_TOWN = "53874"
NEWBERN_CDP = "52506"
NEWBERRY_TOWN = "52524"
NEWBURGH_TOWN = "52650"
NEWPORT_TOWN = "53496"
NEWTONVILLE_CDP = "53676"
NEWTOWN_TOWN = "53694"
NINEVEH_CDP = "53982"
NOBLESVILLE_CITY = "54180"
NORTH_CROWS_NEST_TOWN = "54612"
NORTH_GROVE_CDP = "54792"
NORTH_JUDSON_TOWN = "54900"
NORTH_LIBERTY_TOWN = "54918"
NORTH_MANCHESTER_TOWN = "54954"
NORTH_SALEM_TOWN = "55080"
NORTH_TERRE_HAUTE_CDP = "55098"
NORTH_VERNON_CITY = "55116"
NORTH_WEBSTER_TOWN = "55134"
NORWAY_CDP = "55350"
NOTRE_DAME_CDP = "55386"
NYONA_LAKE_CDP = "55512"
OAKLAND_CITY_CITY = "55710"
OAKTOWN_TOWN = "55800"
OAKVILLE_CDP = "55818"
ODON_TOWN = "56052"
OGDEN_DUNES_TOWN = "56088"
OLDENBURG_TOWN = "56286"
ONTARIO_CDP = "56646"
ONWARD_TOWN = "56664"
OOLITIC_TOWN = "56682"
ORA_CDP = "56700"
ORESTES_TOWN = "56952"
ORLAND_TOWN = "57006"
ORLEANS_TOWN = "57024"
OSCEOLA_TOWN = "57114"
OSGOOD_TOWN = "57132"
OSSIAN_TOWN = "57168"
OSWEGO_CDP = "57186"
OTISCO_CDP = "57222"
OTTER_LAKE_CDP = "57330"
OTTERBEIN_TOWN = "57258"
OTWELL_CDP = "57384"
OWENSBURG_CDP = "57510"
OWENSVILLE_TOWN = "57528"
OXFORD_TOWN = "57546"
PAINTED_HILLS_CDP = "57632"
PALESTINE_CDP = "57672"
PALMYRA_TOWN = "57726"
PAOLI_TOWN = "57780"
PARAGON_TOWN = "57870"
PARIS_CROSSING_CDP = "57924"
PARKER_CITY_TOWN = "57978"
PARKERS_SETTLEMENT_CDP = "58050"
PATOKA_TOWN = "58320"
PATRICKSBURG_CDP = "58374"
PATRIOT_TOWN = "58392"
PAXTON_CDP = "58500"
PENCE_CDP = "58644"
PENDLETON_TOWN = "58662"
PENNTOWN_CDP = "58770"
PENNVILLE_TOWN = "58788"
PEPPERTOWN_CDP = "58878"
PERKINSVILLE_CDP = "58932"
PERRYSVILLE_TOWN = "59238"
PERU_CITY = "59328"
PETERSBURG_CITY = "59364"
PETERSVILLE_CDP = "59400"
PETROLEUM_CDP = "59418"
PHILADELPHIA_CDP = "59490"
PIERCETON_TOWN = "59598"
PIERCEVILLE_CDP = "59616"
PINE_VILLAGE_TOWN = "60084"
PITTSBORO_TOWN = "60192"
PITTSBURG_CDP = "60210"
PLAINFIELD_TOWN = "60246"
PLAINVILLE_TOWN = "60264"
PLEASANT_LAKE_CDP = "60534"
PLEASANT_MILLS_CDP = "60552"
PLEASANT_VIEW_CDP = "60678"
PLEASANT_VIEW_VILLAGE_CDP = "60696"
PLEASANTVILLE_CDP = "60732"
PLYMOUTH_CITY = "60822"
POINT_ISABEL_CDP = "60894"
POLAND_CDP = "60912"
PONETO_TOWN = "61020"
PORTAGE_CITY = "61092"
PORTER_TOWN = "61164"
PORTLAND_CITY = "61236"
POSEYVILLE_TOWN = "61416"
POTTAWATTAMIE_PARK_TOWN = "61470"
PRAIRIE_CREEK_CDP = "61686"
PRAIRIETON_CDP = "61758"
PREBLE_CDP = "61866"
PRINCES_LAKES_TOWN = "62028"
PRINCETON_CITY = "62046"
PROSPECT_CDP = "62154"
PULASKI_CDP = "62280"
PUTNAMVILLE_CDP = "62406"
RAGLESVILLE_CDP = "62712"
RAGSDALE_CDP = "62730"
RAINSVILLE_CDP = "62856"
RAMSEY_CDP = "62892"
RAUB_CDP = "63072"
REDDINGTON_CDP = "63432"
REDKEY_TOWN = "63450"
REMINGTON_TOWN = "63756"
RENSSELAER_CITY = "63792"
REO_CDP = "63810"
REYNOLDS_TOWN = "63918"
RICHLAND_TOWN = "64206"
RICHMOND_CITY = "64260"
RIDGEVILLE_TOWN = "64422"
RILEY_TOWN = "64512"
RISING_SUN_CITY = "64674"
RIVER_FOREST_TOWN = "64728"
RIVERWOOD_CDP = "64944"
ROACHDALE_TOWN = "64980"
ROANN_TOWN = "64998"
ROANOKE_TOWN = "65016"
ROB_ROY_CDP = "65178"
ROCHESTER_CITY = "65214"
ROCKFIELD_CDP = "65358"
ROCKFORD_CDP = "65376"
ROCKPORT_CITY = "65484"
ROCKVILLE_TOWN = "65520"
ROCKY_RIPPLE_TOWN = "65556"
ROLL_CDP = "65592"
ROLLING_PRAIRIE_CDP = "65736"
ROME_CITY_TOWN = "65808"
ROMNEY_CDP = "65826"
ROSEDALE_TOWN = "65934"
ROSELAND_TOWN = "65988"
ROSELAWN_CDP = "66006"
ROSSVILLE_TOWN = "66150"
ROYAL_CENTER_TOWN = "66222"
ROYERTON_CDP = "66312"
RUSHVILLE_CITY = "66438"
RUSSELLVILLE_TOWN = "66510"
RUSSIAVILLE_TOWN = "66546"
SALAMONIA_TOWN = "67302"
SALEM_CITY = "67464"
SALINE_CITY_CDP = "67518"
SALT_CREEK_COMMONS_CDP = "67608"
SALTILLO_TOWN = "67626"
SAN_PIERRE_CDP = "68004"
SANDBORN_TOWN = "67698"
SANDUSKY_CDP = "67896"
SANTA_CLAUS_TOWN = "68022"
SARATOGA_TOWN = "68058"
SARDINIA_CDP = "68076"
SAUGANY_LAKE_CDP = "68103"
SCHAEFER_LAKE_CDP = "68202"
SCHERERVILLE_TOWN = "68220"
SCHNEIDER_TOWN = "68238"
SCHNELLVILLE_CDP = "68256"
SCIPIO_CDP = "68328"
SCIRCLEVILLE_CDP = "68364"
SCOTLAND_CDP = "68382"
SCOTT_CDP = "68418"
SCOTTSBURG_CITY = "68526"
SEELYVILLE_TOWN = "68652"
SELLERSBURG_TOWN = "68670"
SELMA_TOWN = "68706"
SERVIA_CDP = "68742"
SEYMOUR_CITY = "68832"
SHADELAND_TOWN = "68868"
SHAMROCK_LAKES_TOWN = "68976"
SHARPSVILLE_TOWN = "69048"
SHELBURN_TOWN = "69192"
SHELBY_CDP = "69246"
SHELBYVILLE_CITY = "69318"
SHEPARDSVILLE_CDP = "69336"
SHERIDAN_TOWN = "69354"
SHIPSHEWANA_LAKE_CDP = "69489"
SHIPSHEWANA_TOWN = "69480"
SHIRLEY_TOWN = "69516"
SHOALS_TOWN = "69552"
SHOREWOOD_FOREST_CDP = "69642"
SIDNEY_TOWN = "69678"
SILVER_LAKE_TOWN = "69768"
SIMONTON_LAKE_CDP = "69840"
SIMS_CDP = "69894"
SMITHVILLE_SANDERS_CDP = "70330"
SNOW_LAKE_CDP = "70470"
SOLSBERRY_CDP = "70506"
SOMERSET_CDP = "70524"
SOMERVILLE_TOWN = "70542"
SOUTH_BEND_CITY = "71000"
SOUTH_CENTER_CDP = "71072"
SOUTH_HAVEN_CDP = "71288"
SOUTH_MILFORD_CDP = "71396"
SOUTH_WHITLEY_TOWN = "71612"
SOUTHPORT_CITY = "71486"
SPARTANBURG_CDP = "71774"
SPEEDWAY_TOWN = "71828"
SPENCER_TOWN = "71972"
SPENCERVILLE_CDP = "71990"
SPICELAND_TOWN = "72008"
SPRING_GROVE_TOWN = "72206"
SPRING_HILL_TOWN = "72232"
SPRING_LAKE_TOWN = "72296"
SPRINGPORT_TOWN = "72332"
SPURGEON_TOWN = "72440"
ST_ANTHONY_CDP = "66744"
ST_BERNICE_CDP = "66762"
ST_JOE_TOWN = "66834"
ST_JOHN_TOWN = "66852"
ST_LEON_TOWN = "66978"
ST_MARY_OF_THE_WOODS_CDP = "67050"
ST_MEINRAD_CDP = "67176"
ST_OMER_CDP = "67194"
ST_PAUL_TOWN = "67212"
ST_WENDEL_CDP = "67284"
STANFORD_CDP = "72584"
STAR_CITY_CDP = "72638"
STATE_LINE_CITY_TOWN = "72764"
STAUNTON_TOWN = "72782"
STENDAL_CDP = "72980"
STEWARTSVILLE_CDP = "73160"
STILESVILLE_TOWN = "73178"
STILLWELL_CDP = "73214"
STINESVILLE_TOWN = "73232"
STOCKWELL_CDP = "73340"
STONE_BLUFF_CDP = "73376"
STRAUGHN_TOWN = "73664"
STROH_CDP = "73790"
SULLIVAN_CITY = "74006"
SULPHUR_SPRINGS_TOWN = "74060"
SUMAVA_RESORTS_CDP = "74078"
SUMMITVILLE_TOWN = "74132"
SUNMAN_TOWN = "74168"
SWAYZEE_TOWN = "74510"
SWEETSER_TOWN = "74546"
SWITZ_CITY_TOWN = "74582"
SYRACUSE_TOWN = "74744"
TAB_CDP = "74780"
TALMA_CDP = "74870"
TASWELL_CDP = "74978"
TAYLORSVILLE_CDP = "75104"
TECUMSEH_CDP = "75176"
TEEGARDEN_CDP = "75194"
TELL_CITY_CITY = "75248"
TEMPLETON_CDP = "75284"
TENNYSON_TOWN = "75302"
TERRE_HAUTE_CITY = "75428"
THAYER_CDP = "75518"
THORNTOWN_TOWN = "75626"
TIPPECANOE_CDP = "75860"
TIPTON_CITY = "75986"
TOAD_HOP_CDP = "76022"
TOCSIN_CDP = "76076"
TOPEKA_TOWN = "76184"
TOWN_OF_PINES_TOWN = "76256"
TRAFALGAR_TOWN = "76310"
TRAIL_CREEK_TOWN = "76328"
TRI_LAKES_CDP = "76526"
TROY_TOWN = "76634"
TUNNELTON_CDP = "76742"
TWELVE_MILE_CDP = "76886"
TYNER_CDP = "77030"
ULEN_TOWN = "77066"
UNDERWOOD_CDP = "77084"
UNION_CITY_CITY = "77768"
UNION_MILLS_CDP = "77804"
UNIONDALE_TOWN = "77786"
UNIVERSAL_TOWN = "77912"
UPLAND_TOWN = "77966"
URBANA_CDP = "78056"
UTICA_TOWN = "78110"
VALLONIA_CDP = "78290"
VALPARAISO_CITY = "78326"
VAN_BIBBER_LAKE_CDP = "78380"
VAN_BUREN_TOWN = "78470"
VEEDERSBURG_TOWN = "78740"
VELPEN_CDP = "78758"
VERA_CRUZ_TOWN = "78776"
VERNON_TOWN = "78902"
VERSAILLES_TOWN = "78974"
VEVAY_TOWN = "79010"
VICKSBURG_CDP = "79028"
VINCENNES_CITY = "79208"
VISTULA_CDP = "79226"
WABASH_CITY = "79370"
WADESVILLE_CDP = "79442"
WAKARUSA_TOWN = "79478"
WALDRON_CDP = "79568"
WALESBORO_CDP = "79604"
WALKERTON_TOWN = "79694"
WALL_LAKE_CDP = "79784"
WALLACE_TOWN = "79730"
WALTON_TOWN = "79964"
WANATAH_TOWN = "80018"
WARREN_PARK_TOWN = "80234"
WARREN_TOWN = "80108"
WARRINGTON_CDP = "80288"
WARSAW_CITY = "80306"
WASHINGTON_CITY = "80504"
WATERLOO_TOWN = "81278"
WAVELAND_TOWN = "81458"
WAVERLY_CDP = "81494"
WAWAKA_CDP = "81530"
WAYNESVILLE_CDP = "82034"
WAYNETOWN_TOWN = "82052"
WEBSTER_CDP = "82142"
WELLSBORO_CDP = "82250"
WEST_BADEN_SPRINGS_TOWN = "82376"
WEST_COLLEGE_CORNER_TOWN = "82556"
WEST_HARRISON_TOWN = "82790"
WEST_LAFAYETTE_CITY = "82862"
WEST_LEBANON_TOWN = "82934"
WEST_MIDDLETON_CDP = "83042"
WEST_POINT_CDP = "83222"
WEST_TERRE_HAUTE_TOWN = "83384"
WESTFIELD_CITY = "82700"
WESTPHALIA_CDP = "83204"
WESTPORT_TOWN = "83276"
WESTVILLE_TOWN = "83420"
WESTWOOD_CDP = "83456"
WHEATFIELD_TOWN = "83528"
WHEATLAND_TOWN = "83564"
WHEELER_CDP = "83600"
WHITELAND_TOWN = "83816"
WHITESTOWN_TOWN = "84014"
WHITEWATER_TOWN = "84086"
WHITING_CITY = "84122"
WILDWOOD_CDP = "84234"
WILKINSON_TOWN = "84302"
WILLIAMS_CDP = "84338"
WILLIAMS_CREEK_TOWN = "84374"
WILLIAMSBURG_CDP = "84356"
WILLIAMSPORT_TOWN = "84410"
WILLOW_BRANCH_CDP = "84482"
WINAMAC_TOWN = "84734"
WINCHESTER_CITY = "84752"
WINDFALL_CITY_TOWN = "84806"
WINDSOR_CDP = "84842"
WINFIELD_TOWN = "84878"
WINGATE_TOWN = "84914"
WINONA_LAKE_TOWN = "84950"
WINSLOW_TOWN = "84968"
WOLCOTT_TOWN = "85058"
WOLCOTTVILLE_TOWN = "85076"
WOLFLAKE_CDP = "85130"
WOODBURN_CITY = "85184"
WOODLAWN_HEIGHTS_TOWN = "85400"
WOOSTER_CDP = "85562"
WORTHINGTON_TOWN = "85598"
WYATT_CDP = "85724"
WYNNEDALE_TOWN = "85742"
YEOMAN_TOWN = "85886"
YORKTOWN_TOWN = "86084"
YOUNG_AMERICA_CDP = "86156"
ZANESVILLE_TOWN = "86318"
ZIONSVILLE_TOWN = "86372"
